@@ -21,14 +21,18 @@
 #include "kmplayer_atom.h"
 #include "kmplayer_smil.h"
 
+#include <QTextStream>
+
 using namespace KMPlayer;
 
 Node *ATOM::Feed::childFromTag (const QString & tag) {
-    if (!strcmp (tag.latin1 (), "entry"))
+    QByteArray ba = tag.toLatin1 ();
+    const char *name = ba.constData ();
+    if (!strcmp (name, "entry"))
         return new ATOM::Entry (m_doc);
-    else if (!strcmp (tag.latin1 (), "link"))
+    else if (!strcmp (name, "link"))
         return new ATOM::Link (m_doc);
-    else if (!strcmp (tag.latin1 (), "title"))
+    else if (!strcmp (name, "title"))
         return new DarkNode (m_doc, tag.toUtf8 (), id_node_title);
     return NULL;
 }
@@ -36,7 +40,7 @@ Node *ATOM::Feed::childFromTag (const QString & tag) {
 void ATOM::Feed::closed () {
     for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
-            title = c->innerText ().simplifyWhiteSpace ();
+            title = c->innerText ().simplified ();
             break;
         }
     Element::closed ();
@@ -50,7 +54,8 @@ void *ATOM::Feed::role (RoleType msg, void *content)
 }
 
 Node *ATOM::Entry::childFromTag (const QString &tag) {
-    const char *cstr = tag.latin1 ();
+    QByteArray ba = tag.toLatin1 ();
+    const char *cstr = ba.constData ();
     if (!strcmp (cstr, "link"))
         return new ATOM::Link (m_doc);
     else if (!strcmp (cstr, "content"))
@@ -78,14 +83,14 @@ void ATOM::Entry::closed () {
     Node *rating = NULL;
     for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
-            title = c->innerText ().simplifyWhiteSpace ();
+            title = c->innerText ().simplified ();
         } else if (c->id == id_node_gd_rating) {
             rating = c;
         } else if (c->id == id_node_media_group) {
             group = static_cast <MediaGroup *> (c);
         }
     if (group)
-        group->addSummary (this, rating);
+        group->addSummary (this, rating, QString(), QString(), QString(), 0, 0);
     Element::closed ();
 }
 
@@ -123,7 +128,7 @@ void ATOM::Content::closed () {
         if (a->name () == Ids::attr_src)
             src = a->value ();
         else if (a->name () == Ids::attr_type) {
-            QString v = a->value ().lower ();
+            QString v = a->value ().toLower ();
             if (v == QString::fromLatin1 ("text"))
                 mimetype = QString::fromLatin1 ("text/plain");
             else if (v == QString::fromLatin1 ("html"))
@@ -144,7 +149,8 @@ Node::PlayType ATOM::Content::playType () {
 }
 
 Node *ATOM::MediaGroup::childFromTag (const QString &tag) {
-    const char *cstr = tag.latin1 ();
+    QByteArray ba = tag.toLatin1 ();
+    const char *cstr = ba.constData ();
     if (!strcmp (cstr, "media:content"))
         return new ATOM::MediaContent (m_doc);
     else if (!strcmp (cstr, "media:title"))
@@ -188,8 +194,18 @@ static QString makeStar (int x, bool fill) {
     return path;
 }
 
+static QString makeImage(const QString& url, int width, int height) {
+    QString str = QString ("<img region=\"image\" src=\"") + url + QChar ('"');
+    if (width && height) {
+        str += QString(" width=\"%1\" height=\"%2\"").arg(width).arg(height);
+    }
+    str += QString (" dur=\"20\" transIn=\"fade\" fill=\"transition\" fit=\"meet\"/>");
+    return str;
+}
+
 //http://code.google.com/apis/youtube/2.0/developers_guide_protocol.html
-void ATOM::MediaGroup::addSummary (Node *p, Node *rating_node) {
+void ATOM::MediaGroup::addSummary(Node *p, Node *rating_node,
+        const QString& alt_title, const QString& alt_desc, const QString& alt_img, int width, int height) {
     QString images;
     QString desc;
     QString title;
@@ -224,23 +240,25 @@ void ATOM::MediaGroup::addSummary (Node *p, Node *rating_node) {
             Element *e = static_cast <Element *> (c);
             QString url = e->getAttribute (Ids::attr_url);
             if (!url.isEmpty ()) {
-                images += QString ("<img region=\"image\" src=\"") + url + QChar ('"');
-                QString w = e->getAttribute (Ids::attr_width);
-                if (!w.isEmpty ())
-                    images += QString (" width=\"") + w + QChar ('"');
-                QString h = e->getAttribute (Ids::attr_height);
-                if (!h.isEmpty ())
-                    images += QString (" height=\"") + h + QChar ('"');
-                images += QString (" dur=\"20\" transIn=\"fade\" fill=\"transition\" fit=\"meet\"/>");
+                images += makeImage(url, e->getAttribute (Ids::attr_width).toInt(),
+                                         e->getAttribute (Ids::attr_height).toInt());
                 img_count++;
             }
             break;
         }
         }
     }
+    if (title.isEmpty())
+        title = alt_title;
+    if (desc.isEmpty())
+        desc = alt_desc;
+    if (!img_count && !alt_img.isEmpty()) {
+        images = makeImage(alt_img, width, height);
+        ++img_count;
+    }
     if (img_count) {
         QString buf;
-        QTextOStream out (&buf);
+        QTextStream out (&buf, QIODevice::WriteOnly);
         out << "<smil><head>";
         if (!title.isEmpty ())
             out << "<title>" << title << "</title>";
@@ -284,7 +302,9 @@ void ATOM::MediaGroup::addSummary (Node *p, Node *rating_node) {
 
 void ATOM::MediaContent::closed () {
     unsigned fsize = 0;
+    unsigned bitrate = 0;
     TrieString fs ("fileSize");
+    TrieString rate ("bitrate");
     for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
         if (a->name () == Ids::attr_url)
             src = a->value();
@@ -298,6 +318,8 @@ void ATOM::MediaContent::closed () {
             size.width = a->value ().toInt ();
         else if (a->name () == fs)
             fsize = a->value ().toInt ();
+        else if (a->name () == rate)
+            bitrate = a->value ().toInt ();
     }
     if (!mimetype.isEmpty ()) {
         title = mimetype;
@@ -306,6 +328,11 @@ void ATOM::MediaContent::closed () {
                 title += QString (" (%1 Mb)").arg (fsize / (1024 * 1024));
             else
                 title += QString (" (%1 kb)").arg (fsize / 1024);
+        } else if (bitrate > 0) {
+            if (bitrate > 10 * 1024)
+                title += QString(" (%1 Mbit/s)").arg(bitrate / 1024);
+            else
+                title += QString(" (%1 kbit/s)").arg(bitrate);
         }
     }
     Mrl::closed ();
