@@ -35,26 +35,34 @@ const short id_node_link = 302;
 const short id_node_title = 303;
 const short id_node_summary = 304;
 const short id_node_content = 305;
+const short id_node_media_group = 306;
+const short id_node_media_content = 307;
+const short id_node_media_title = 308;
+const short id_node_media_description = 309;
+const short id_node_media_player = 310;
+const short id_node_media_thumbnail = 311;
+const short id_node_gd_rating = 312;
+const short id_node_ignored = 313;
 
 /**
  * '<feed>' tag
  */
-class Feed : public Mrl {
+class KMPLAYER_NO_EXPORT Feed : public Element, public PlaylistRole {
 public:
-    KDE_NO_CDTOR_EXPORT Feed (NodePtr & d) : Mrl (d, id_node_feed) {}
-    NodePtr childFromTag (const QString & tag);
+    KDE_NO_CDTOR_EXPORT Feed (NodePtr & d) : Element (d, id_node_feed) {}
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "feed"; }
     void closed ();
-    bool expose () const { return !pretty_name.isEmpty (); }
+    void *role (RoleType msg, void *content=NULL);
 };
 
-class KMPLAYER_NO_EXPORT Entry : public Mrl {
+class KMPLAYER_NO_EXPORT Entry : public Element, public PlaylistRole {
 public:
-    KDE_NO_CDTOR_EXPORT Entry (NodePtr & d) : Mrl (d, id_node_entry) {}
-    NodePtr childFromTag (const QString & tag);
+    KDE_NO_CDTOR_EXPORT Entry (NodePtr & d) : Element (d, id_node_entry) {}
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "entry"; }
-    PlayType playType () { return play_type_none; }
     void closed ();
+    void *role (RoleType msg, void *content=NULL);
 };
 
 class KMPLAYER_NO_EXPORT Link : public Mrl {
@@ -71,7 +79,23 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "content"; }
     PlayType playType ();
     void closed ();
-    //bool expose () const { return isPlayable (); }
+};
+
+class KMPLAYER_NO_EXPORT MediaGroup : public Element {
+public:
+    MediaGroup (NodePtr &d) : Element (d, id_node_media_group) {}
+    Node *childFromTag (const QString &tag);
+    void message (MessageType msg, void *content=NULL);
+    KDE_NO_EXPORT const char *nodeName () const { return "media:group"; }
+    void addSummary (Node *parent, Node *ratings, const QString& alt_title, const QString& alt_desc,
+                     const QString& alt_img, int width, int height);
+};
+
+class KMPLAYER_NO_EXPORT MediaContent : public Mrl {
+public:
+    MediaContent (NodePtr &d) : Mrl (d, id_node_media_content) {}
+    KDE_NO_EXPORT const char *nodeName () const { return "media:content"; }
+    void closed ();
 };
 
 } //namespace ATOM
