@@ -21,10 +21,11 @@
 #include <qurl.h>
 #include <qtextstream.h>
 #include <qbytearray.h>
+#include <qinputdialog.h>
+#include <QStandardPaths>
 
-#include <kstandarddirs.h>
-#include <kinputdialog.h>
 #include <kfiledialog.h>
+#include <ksharedconfig.h>
 #include <klocale.h>
 #include <kdebug.h>
 
@@ -51,7 +52,7 @@ QString ListsSource::prettyName ()
 }
 
 KDE_NO_CDTOR_EXPORT FileDocument::FileDocument (short i, const QString &s, KMPlayer::Source *src)
- : KMPlayer::SourceDocument (src, s) {
+ : KMPlayer::SourceDocument (src, s), load_tree_version ((unsigned int)-1) {
     id = i;
 }
 
@@ -67,9 +68,11 @@ void FileDocument::readFromFile (const QString & fn) {
     if (QFileInfo (file).exists ()) {
         file.open (QIODevice::ReadOnly);
         QTextStream inxml (&file);
+        inxml.setCodec("UTF-8");
         KMPlayer::readXML (this, inxml, QString (), false);
         normalize ();
     }
+    load_tree_version = m_tree_version;
 }
 
 void FileDocument::writeToFile (const QString & fn) {
@@ -77,12 +80,20 @@ void FileDocument::writeToFile (const QString & fn) {
     kDebug () << "writeToFile " << fn;
     file.open (QIODevice::WriteOnly | QIODevice::Truncate);
     file.write (outerXML ().toUtf8 ());
+    load_tree_version = m_tree_version;
+}
+
+void FileDocument::sync (const QString &fn)
+{
+    if (resolved && load_tree_version != m_tree_version)
+        writeToFile (fn);
 }
 
 KDE_NO_CDTOR_EXPORT Recents::Recents (KMPlayerApp *a)
     : FileDocument (id_node_recent_document, "recents://"),
       app(a) {
     title = i18n ("Most Recent");
+    bookmarkable = false;
 }
 
 KDE_NO_EXPORT void Recents::activate () {
@@ -93,7 +104,7 @@ KDE_NO_EXPORT void Recents::activate () {
 KDE_NO_EXPORT void Recents::defer () {
     if (!resolved) {
         resolved = true;
-        readFromFile (KStandardDirs::locateLocal ("data", "kmplayer/recent.xml"));
+        readFromFile(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kmplayer/recent.xml");
     }
 }
 
@@ -158,11 +169,14 @@ void *Group::role (KMPlayer::RoleType msg, void *content)
 }
 
 KDE_NO_EXPORT void Playlist::defer () {
-    if (playmode)
+    if (playmode) {
         KMPlayer::Document::defer ();
-    else if (!resolved) {
+        // Hack: Node::undefer will restart first item when state=init
+        if (firstChild() && KMPlayer::Node::state_init == firstChild()->state)
+            firstChild()->state = KMPlayer::Node::state_activated;
+    } else if (!resolved) {
         resolved = true;
-        readFromFile (KStandardDirs::locateLocal ("data", "kmplayer/playlist.xml"));
+        readFromFile(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kmplayer/playlist.xml");
     }
 }
 
@@ -178,6 +192,7 @@ KDE_NO_CDTOR_EXPORT Playlist::Playlist (KMPlayerApp *a, KMPlayer::Source *s, boo
       app(a),
       playmode (plmode) {
     title = i18n ("Persistent Playlists");
+    bookmarkable = false;
 }
 
 KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const QString & tag) {
@@ -296,6 +311,7 @@ KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr &doc, KMPlayerApp *a, const QString &pn)
   : KMPlayer::Element (doc, KMPlayer::id_node_group_node), app (a), playmode (false) {
     title = pn;
+    editable = true;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::Ids::attr_title, pn);
 }
@@ -400,7 +416,7 @@ QString Generator::genReadAsk (KMPlayer::Node *n) {
     QString key = static_cast<Element*>(n)->getAttribute ("key");
     QString def = static_cast<Element*>(n)->getAttribute ("default");
     QString input;
-    KConfigGroup cfg (KGlobal::config(), "Generator Defaults");
+    KConfigGroup cfg(KSharedConfig::openConfig(), "Generator Defaults");
     if (!key.isEmpty ())
         def = cfg.readEntry (key, def);
     if (type == "file") {
@@ -419,7 +435,7 @@ QString Generator::genReadAsk (KMPlayer::Node *n) {
                     desc = c->innerText ().simplified ();
                     break;
             }
-        input = KInputDialog::getText (title, desc, def);
+        input = QInputDialog::getText(0, title, desc, QLineEdit::Normal, def);
     }
     if (input.isNull ())
         canceled = true;
@@ -496,7 +512,7 @@ QString Generator::genReadString (KMPlayer::Node *n) {
              str += c->nodeValue ().simplified ();
         }
     if (find_resource)
-        str = KStandardDirs().findResource ("data", str);
+        str = QStandardPaths::locate(QStandardPaths::GenericDataLocation, str);
     if (!static_cast <Element *>(n)->getAttribute ("encoding").isEmpty ())
         str = QUrl::toPercentEncoding (str);
     if (need_quote) {
