@@ -22,23 +22,24 @@
 #include <list>
 #include <algorithm>
 
+#include <qlabel.h>
 #include <qmenu.h>
 #include <qtimer.h>
 #include <qpushbutton.h>
 #include <qslider.h>
 #include <QFile>
 #include <QMetaObject>
+#include <QStandardPaths>
 
 class KXMLGUIClient; // workaround for kde3.3 on sarge with gcc4, kactioncollection.h does not forward declare KXMLGUIClient
-#include <kaboutdata.h>
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kaction.h>
-#include <kauthorized.h>
+#include <kurlauthorized.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kparts/factory.h>
 #include <kstatusbar.h>
-#include <kstandarddirs.h>
 
 #include "kmplayer_part.h"
 #include "kmplayerview.h"
@@ -96,51 +97,36 @@ struct KMPLAYER_NO_EXPORT GroupPredicate {
 
 //-----------------------------------------------------------------------------
 
-class KMPLAYER_NO_EXPORT KMPlayerFactory : public KParts::Factory {
-public:
-    KMPlayerFactory ();
-    virtual ~KMPlayerFactory ();
-    virtual KParts::Part *createPartObject (QWidget *wparent=NULL, QObject *parent=NULL,
-         const char *className="KParts::Part", const QStringList &args=QStringList());
-    static const KComponentData &componentData();
-    static KAboutData *aboutData ();
-private:
-    static KComponentData *s_instance;
-};
-
 K_EXPORT_PLUGIN(KMPlayerFactory)
 
-KComponentData *KMPlayerFactory::s_instance = 0L;
+KAboutData* KMPlayerFactory::s_about = 0L;
 
 KDE_NO_CDTOR_EXPORT KMPlayerFactory::KMPlayerFactory () {
 }
 
 KDE_NO_CDTOR_EXPORT KMPlayerFactory::~KMPlayerFactory () {
-    delete s_instance;
 }
 
-KDE_NO_EXPORT KParts::Part *KMPlayerFactory::createPartObject
-  (QWidget *wparent, QObject *parent, const char * cls, const QStringList & args) {
-      kDebug() << "KMPlayerFactory::createPartObject " << cls;
-      return new KMPlayerPart (wparent, parent, args);
+KAboutData& KMPlayerFactory::aboutData() {
+    if (!s_about) {
+        s_about = new KAboutData("kmplayer", i18n("KMPlayer"), QStringLiteral(KMPLAYER_VERSION_STRING),
+                i18n("Embedded MPlayer for KDE"),
+                KAboutLicense::LGPL);
+        s_about->addAuthor(QStringLiteral("Koos Vriezen"), QString(), "koos.vriezen@gmail.com");
+    }
+    return *s_about;
 }
 
-const KComponentData &KMPlayerFactory::componentData () {
-    kDebug () << "KMPlayerFactory::instance";
-    if (!s_instance)
-        s_instance = new KComponentData (aboutData ());
-    return *s_instance;
-}
-
-KAboutData *KMPlayerFactory::aboutData () {
-    KAboutData *about = new KAboutData("plugin", 0, ki18n("plugin"), "1.99");
-    return about;
+QObject* KMPlayerFactory::create(const char *iface, QWidget* parentWidget, QObject* parent,
+        const QVariantList& args, const QString&)
+{
+    return new KMPlayerPart(parentWidget, parent, args);
 }
 
 //-----------------------------------------------------------------------------
 
 GrabDocument::GrabDocument (KMPlayerPart *part, const QString &url,
-        const QString &file, PlayListNotify * n)
+        const QString &file, PlayListNotify *)
  : SourceDocument (part->sources () ["urlsource"], url),
    m_grab_file (file),
    m_part (part) {
@@ -179,32 +165,35 @@ void GrabDocument::message (MessageType msg, void *content) {
 //-----------------------------------------------------------------------------
 
 static bool getBoolValue (const QString & value) {
-    return (value.lower() != QString::fromLatin1("false") &&
-            value.lower() != QString::fromLatin1("off") &&
-            value.lower() != QString::fromLatin1("0"));
+    return (value.toLower() != QString::fromLatin1("false") &&
+            value.toLower() != QString::fromLatin1("off") &&
+            value.toLower() != QString::fromLatin1("0"));
 }
 
 #define SET_FEAT_ON(f) { m_features |= f; turned_off_features &= ~f; }
 #define SET_FEAT_OFF(f) { m_features &= ~f; turned_off_features |= f; }
 
 KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (QWidget *wparent,
-                    QObject *ppart, const QStringList &args)
+                    QObject* ppart, const QVariantList& args)
  : PartBase (wparent, ppart, KSharedConfig::openConfig ("kmplayerrc")),
    m_master (0L),
    m_browserextension (new KMPlayerBrowserExtension (this)),
    m_liveconnectextension (new KMPlayerLiveConnectExtension (this)),
+   m_playtime_info(0),
    m_expected_view_width (0),
    m_expected_view_height (0),
    m_features (Feat_Unknown),
    m_started_emited (false),
-   m_wait_npp_loaded (true) {
+   m_wait_npp_loaded (false)
+{
+    setComponentData(KMPlayerFactory::aboutData());
     kDebug () << "KMPlayerPart(" << this << ")::KMPlayerPart ()";
     bool show_fullscreen = false;
     if (!kmplayerpart_static)
         (void) new KMPlayerPartStatic (&kmplayerpart_static);
     else
         kmplayerpart_static->ref ();
-    setComponentData (KMPlayerFactory::componentData ());
+    setComponentData(KMPlayerFactory::aboutData ());
     init (actionCollection (),
          QString ("/KMPlayerPart%1").arg(kmplayerpart_static->counter++), true);
     createBookmarkMenu (m_view->controlPanel ()->bookmarkMenu, actionCollection ());
@@ -216,14 +205,15 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (QWidget *wparent,
     //new KAction (i18n ("Decrease Volume"), QString ("player_volume"), KShortcut (), this, SLOT (decreaseVolume ()), actionCollection (), "edit_volume_down");
     Source *source = m_sources ["urlsource"];
     KMPlayer::ControlPanel * panel = m_view->controlPanel ();
-    QStringList::const_iterator it = args.begin ();
-    QStringList::const_iterator end = args.end ();
+    QVariantList::const_iterator it = args.begin ();
+    QVariantList::const_iterator end = args.end ();
     int turned_off_features = 0;
     for ( ; it != end; ++it) {
-        int equalPos = (*it).find("=");
+        QString arg = (*it).toString();
+        int equalPos = arg.indexOf("=");
         if (equalPos > 0) {
-            QString name = (*it).left (equalPos).lower ();
-            QString value = (*it).right ((*it).size () - equalPos - 1);
+            QString name = arg.left(equalPos).toLower();
+            QString value = arg.right(arg.size() - equalPos - 1);
             if (value.at(0)=='\"')
                 value = value.right (value.size () - 1);
             if (value.at (value.size () - 1) == '\"')
@@ -239,19 +229,13 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (QWidget *wparent,
             } else if (name == QString::fromLatin1("height")) {
                 m_noresize = true;
                 m_expected_view_height = value.toInt ();
-            } else if (name == QString::fromLatin1("type")) {
-                source->document ()->mrl ()->mimetype = value;
-                if (value == "application/x-shockwave-flash" ||
-                        value == "application/futuresplash")
-                    m_wait_npp_loaded = true;
             } else if (name == QString::fromLatin1("controls")) {
                 //http://service.real.com/help/library/guides/production8/realpgd.htm?src=noref,rnhmpg_080301,rnhmtn,nosrc
                 //http://service.real.com/help/library/guides/production8/htmfiles/control.htm
-                QStringList sl = QStringList::split (QChar (','), value);
-                QStringList::const_iterator it = sl.constBegin ();
+                QStringList sl = value.split(QChar (','));
                 const QStringList::const_iterator e = sl.constEnd ();
                 for (QStringList::const_iterator i = sl.constBegin (); i != e; ++i) {
-                    QString val_lower ((*i).lower ());
+                    QString val_lower ((*i).toLower ());
                     if (val_lower == QString::fromLatin1("imagewindow")) {
                         SET_FEAT_ON (Feat_ImageWindow | Feat_Viewer)
                     } else if (val_lower == QString::fromLatin1("all")) {
@@ -312,7 +296,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (QWidget *wparent,
                     }
                 }
             } else if (name == QString::fromLatin1("uimode")) {
-                QString val_lower (value.lower ());
+                QString val_lower (value.toLower ());
                 if (val_lower == QString::fromLatin1("full"))
                     SET_FEAT_ON (Feat_All & ~(Feat_PlayList | Feat_ImageWindow))
                 // TODO: invisible, none, mini
@@ -400,8 +384,8 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (QWidget *wparent,
             last_time_left = 0;
             connect (this, SIGNAL (positioned (int, int)),
                      this, SLOT (statusPosition (int, int)));
-            m_view->statusBar ()->insertItem (QString ("--:--"), 1, 0);
-            m_view->statusBar ()->setItemAlignment (1, Qt::AlignRight);
+            m_playtime_info = new QLabel("--:--");
+            m_view->statusBar()->addPermanentWidget(m_playtime_info);
         }
     }
     if (group_member) {
@@ -446,7 +430,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::~KMPlayerPart () {
 
 KDE_NO_EXPORT void KMPlayerPart::processCreated (KMPlayer::Process *p) {
 #ifdef KMPLAYER_WITH_NPP
-    if (!strcmp (p->name (), "npp")) {
+    if (p->objectName() == "npp") {
         if (m_wait_npp_loaded)
             connect (p, SIGNAL (loaded ()), this, SLOT (nppLoaded ()));
         connect (p, SIGNAL (evaluate (const QString &, bool, QString &)),
@@ -463,7 +447,7 @@ KDE_NO_EXPORT void KMPlayerPart::processCreated (KMPlayer::Process *p) {
 }
 
 KDE_NO_EXPORT bool KMPlayerPart::allowRedir (const KUrl & url) const {
-    return KAuthorized::authorizeUrlAction ("redirect", m_docbase, url);
+    return KUrlAuthorized::authorizeUrlAction ("redirect", m_docbase, url);
 }
 
 KDE_NO_EXPORT void KMPlayerPart::setAutoControls (bool b) {
@@ -496,21 +480,33 @@ KDE_NO_EXPORT void KMPlayerPart::viewerPartSourceChanged(Source *o, Source *s) {
     }
 }
 
-KDE_NO_EXPORT bool KMPlayerPart::openUrl (const KUrl & _url) {
-    kDebug () << "KMPlayerPart::openUrl " << _url.url();
+KDE_NO_EXPORT bool KMPlayerPart::openUrl(const QUrl& _url) {
+    KUrl url;
+    KParts::OpenUrlArguments args = arguments ();
     Source * urlsource = m_sources ["urlsource"];
     KMPlayerPartList::iterator i =kmplayerpart_static->partlist.begin ();
     KMPlayerPartList::iterator e =kmplayerpart_static->partlist.end ();
     GroupPredicate pred (this, m_group);
-    KUrl url;
-    if (!m_file_name.isEmpty () && (_url.isEmpty () || _url == m_docbase))
+    bool emit_started = !m_settings->clicktoplay;
+
+    kDebug () << "KMPlayerPart::openUrl " << _url.url() << " " << args.mimeType();;
+    if (args.mimeType () == "application/x-shockwave-flash" ||
+            args.mimeType () == "application/futuresplash") {
+        m_wait_npp_loaded = true;
+        urlsource->setAvoidRedirects (true);
+    }
+
+    if (m_wait_npp_loaded && (_url.isEmpty () || _url == m_docbase)) {
+        url = KUrl ("about:empty");
+        m_wait_npp_loaded = emit_started = false;
+    } else if (!m_file_name.isEmpty () && (_url.isEmpty () || _url == m_docbase)) {
         url = KUrl (m_docbase, m_file_name); // fix misdetected SRC attr
-    else if (_url != m_docbase) {
+    } else if (_url != m_docbase) {
         url = _url;
-        if (!m_file_name.isEmpty () && _url.url ().find (m_file_name) < 0) {
+        if (!m_file_name.isEmpty() && _url.url().indexOf(m_file_name) < 0) {
             KUrl u (m_file_name);
             if ((u.protocol () == QString ("mms")) ||
-                    _url.protocol ().isEmpty ()) {
+                    KUrl(_url).protocol ().isEmpty ()) {
                 // see if we somehow have to merge these
                 int p = _url.port ();
                 if (p > 0)
@@ -534,11 +530,12 @@ KDE_NO_EXPORT bool KMPlayerPart::openUrl (const KUrl & _url) {
                 }
     }
     if (!m_href_url.isEmpty () &&
-            !KAuthorized::authorizeUrlAction (
+            !KUrlAuthorized::authorizeUrlAction (
                 "redirect", url, KUrl (m_docbase, m_href_url)))
            m_href_url.truncate (0);
     if (m_href_url.isEmpty ())
         setUrl (url.url ());
+
     if (url.isEmpty ()) {
         if (!m_master && !(m_features & Feat_Viewer))
             // no master set, wait for a viewer to attach or timeout
@@ -561,13 +558,12 @@ KDE_NO_EXPORT bool KMPlayerPart::openUrl (const KUrl & _url) {
     if (!m_view || !url.isValid ())
         return false;
 
-    KParts::OpenUrlArguments args = arguments ();
     if (!args.mimeType ().isEmpty ())
         urlsource->document ()->mrl ()->mimetype = args.mimeType ();
 
     startUrl (url);
 
-    if (urlsource->autoPlay ()) {
+    if (emit_started && urlsource->autoPlay ()) {
         emit started (0L);
         m_started_emited = true;
     }
@@ -575,7 +571,7 @@ KDE_NO_EXPORT bool KMPlayerPart::openUrl (const KUrl & _url) {
 }
 
 KDE_NO_EXPORT void
-KMPlayerPart::openUrl (const KUrl &u, const QString &t, const QString &srv) {
+KMPlayerPart::openUrl(const QUrl& u, const QString& t, const QString& srv) {
     m_browserextension->requestOpenURL (u, t, srv);
 }
 
@@ -596,7 +592,7 @@ KDE_NO_EXPORT bool KMPlayerPart::startUrl(const KUrl &uri, const QString &img) {
         static int counter;
         m_href_url = KUrl (m_docbase, m_href_url).url ();
         m_grab_file = QString ("%1grab-%2-%3.jpg")
-            .arg (KStandardDirs::locateLocal ("data", "kmplayer/"))
+            .arg (QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+ "kmplayer/")
             .arg (getpid ())
             .arg (counter++);
         Node *n = new GrabDocument (this, url.url (), m_grab_file, src);
@@ -604,6 +600,8 @@ KDE_NO_EXPORT bool KMPlayerPart::startUrl(const KUrl &uri, const QString &img) {
         m_src_url = m_href_url;
         src->setDocument (n, n);
         setSource (src);
+        if (m_source->avoidRedirects ())
+            m_source->activate();
         return true;
     }
     if ((m_settings->clicktoplay || !m_href_url.isEmpty ()) &&
@@ -677,10 +675,13 @@ KDE_NO_EXPORT bool KMPlayerPart::startUrl(const KUrl &uri, const QString &img) {
                 im->mrl ()->access_granted = true;
         }
         doc->document ()->resolved = true;
-        if (m_source)
+        if (m_source) {
             m_source->activate();
-        else
+        } else {
             setSource (src);
+            if (m_source->avoidRedirects ())
+                m_source->activate();
+        }
 #else
         if (m_view->setPicture (KUrl (img).path ())) {
             connect (m_view, SIGNAL (pictureClicked ()),
@@ -753,7 +754,8 @@ KDE_NO_EXPORT void KMPlayerPart::connectToPart (KMPlayerPart * m) {
         last_time_left = 0;
         connect (m, SIGNAL (positioned (int, int)),
                  this, SLOT (statusPosition (int, int)));
-        m_view->statusBar ()->insertItem (QString ("--:--"), 1, 0);
+        m_playtime_info = new QLabel("--:--");
+        m_view->statusBar()->addPermanentWidget(m_playtime_info);
     }
 }
 
@@ -806,6 +808,7 @@ KDE_NO_EXPORT void KMPlayerPart::playingStopped () {
 
 KDE_NO_EXPORT void KMPlayerPart::nppLoaded () {
     if (m_started_emited && m_wait_npp_loaded) {
+        m_wait_npp_loaded = false;
         m_started_emited = false;
         m_browserextension->setLoadingProgress (100);
         emit completed ();
@@ -842,7 +845,7 @@ KDE_NO_EXPORT void KMPlayerPart::statusPosition (int pos, int length) {
             else
                 text.sprintf ("%02d:%02d", m, s);
         }
-        m_view->statusBar ()->changeItem (text, 1);
+        m_playtime_info->setText(text);
     }
 }
 
@@ -1114,7 +1117,7 @@ KDE_NO_EXPORT void KMPlayerLiveConnectExtension::evaluate (
             int p = scr.indexOf ("=null", 21);
             if (p > -1) {
                 int i = scr.mid (21, p - 21).toInt ();
-                if (i == object_counter-1)
+                if (i == (int)object_counter-1)
                     object_counter--; // works most of the time :-)
             }
         }
@@ -1195,7 +1198,7 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::get
         return true;
     }
     if (name.startsWith ("__kmplayer_util_") ||
-            redir_funcs.find (name) != redir_funcs.end ())
+            redir_funcs.indexOf(name) >= 0)
         return false;
     if (name == "__kmplayer_unique_name") {
         rval = QString ("__kmplayer__obj_%1").arg (object_counter);
@@ -1249,13 +1252,13 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::get
                         .arg (name));
                 redir_funcs.push_back (name);
                 m_skip_put = false;
+                return false;
             }
-            return false;
+            return true;
         }
     }
     kDebug () << "[01;35mget[00m " << name;
-    const char * str = name.ascii ();
-    const JSCommandEntry * entry = getJSCommandEntry (str);
+    const JSCommandEntry * entry = getJSCommandEntry (name.toAscii ().constData ());
     if (!entry)
         return false;
     type = entry->rettype;
@@ -1309,7 +1312,7 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::put
 
     kDebug () << "[01;35mput[00m " << name << "=" << val;
 
-    const JSCommandEntry * entry = getJSCommandEntry (name.ascii ());
+    const JSCommandEntry * entry = getJSCommandEntry (name.toAscii ().constData ());
     if (!entry)
         return false;
     switch (entry->command) {
@@ -1403,12 +1406,12 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::call
     }
     kDebug () << "[01;35mentry[00m " << func;
     const JSCommandEntry * entry = lastJSCommandEntry;
-    const char * str = func.ascii ();
-    if (!entry || strcmp (entry->name, str))
-        entry = getJSCommandEntry (str);
+    const QByteArray ascii = func.toAscii ();
+    if (!entry || strcmp (entry->name, ascii.constData ()))
+        entry = getJSCommandEntry (ascii.constData ());
     if (!entry)
         return false;
-    for (unsigned int i = 0; i < args.size (); ++i)
+    for (QStringList::size_type i = 0; i < args.size (); ++i)
         kDebug () << "      " << args[i];
     if (!player->view ())
         return false;
@@ -1419,10 +1422,10 @@ KDE_NO_EXPORT bool KMPlayerLiveConnectExtension::call
                 rval = entry->defaultvalue;
             break;
         case canpause:
-            rval = (player->playing () && !player->viewWidget ()->controlPanel()->button (KMPlayer::ControlPanel::button_pause)->isOn ()) ? "true" : "false";
+            rval = (player->playing () && !player->viewWidget ()->controlPanel()->button (KMPlayer::ControlPanel::button_pause)->isChecked ()) ? "true" : "false";
             break;
         case canplay:
-            rval = (!player->playing () || player->viewWidget ()->controlPanel()->button (KMPlayer::ControlPanel::button_pause)->isOn ()) ? "true" : "false";
+            rval = (!player->playing () || player->viewWidget ()->controlPanel()->button (KMPlayer::ControlPanel::button_pause)->isChecked ()) ? "true" : "false";
             break;
         case canstop:
             rval = player->playing () ? "true" : "false";
