@@ -19,18 +19,36 @@
 #ifndef KMPLAYER_PART_H
 #define KMPLAYER_PART_H
 
+#include <kpluginfactory.h>
 #include <kparts/browserextension.h>
+#include <kparts/liveconnectextension.h>
+#include <kaboutdata.h>
 #include "kmplayerpartbase.h"
-#include "kmplayersource.h"
 #include "config-kmplayer.h"
 
 
+class QLabel;
 class KMPlayerPart;
 class JSCommandEntry;
 namespace KMPlayer {
     class PlayListNotify;
 }
 
+class KMPlayerFactory : public KPluginFactory {
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.KPluginFactory" FILE "")
+    Q_INTERFACES(KPluginFactory)
+public:
+    KMPlayerFactory();
+    virtual ~KMPlayerFactory();
+
+    virtual QObject* create(const char *iface, QWidget* parentWidget, QObject* parent,
+            const QVariantList& args, const QString& keyword) Q_DECL_OVERRIDE;
+    static KAboutData& aboutData();
+private:
+    static KAboutData* s_about;
+};
+
 /*
  * Document to get first frame for streams starting with a picture
  */
@@ -125,7 +143,7 @@ public:
         Feat_InfoPanel = 0x10, Feat_VolumeSlider = 0x20, Feat_PlayList = 0x40,
         Feat_ImageWindow = 0x80, Feat_All = 0xff
     };
-    KMPlayerPart (QWidget *wparent, QObject *parent, const QStringList &args);
+    KMPlayerPart (QWidget *wparent, QObject *parent, const QVariantList &args);
     ~KMPlayerPart ();
 
     KDE_NO_EXPORT KMPlayerBrowserExtension * browserextension() const
@@ -143,16 +161,17 @@ public:
 
     virtual QString doEvaluate (const QString &script);
 
+    using KMPlayer::PartBase::openUrl;
 public slots:
-    virtual bool openUrl (const KUrl & url);
-    virtual void openUrl (const KUrl &, const QString &t, const QString &srv);
+    virtual bool openUrl(const QUrl& url);
+    virtual void openUrl(const QUrl&, const QString& t, const QString& srv);
     virtual bool closeUrl ();
     void setMenuZoom (int id);
 protected:
     virtual void processCreated (KMPlayer::Process *);
-protected slots:
     virtual void playingStarted ();
     virtual void playingStopped ();
+protected slots:
     void viewerPartDestroyed (QObject *);
     void viewerPartProcessChanged (const char *);
     void viewerPartSourceChanged (KMPlayer::Source *, KMPlayer::Source *);
@@ -167,6 +186,7 @@ private:
     KMPlayerPart * m_master;
     KMPlayerBrowserExtension * m_browserextension;
     KMPlayerLiveConnectExtension * m_liveconnectextension;
+    QLabel* m_playtime_info;
     QString m_group;
     QString m_src_url;
     QString m_href_url;
