@@ -49,33 +49,29 @@ const short id_node_tracknum = 516;
 const short id_node_duration = 517;
 const short id_node_link = 518;
 
-class Playlist : public Mrl {
+class KMPLAYER_NO_EXPORT Playlist : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Playlist (NodePtr & d) : Mrl (d, id_node_playlist) {}
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
-    bool expose () const { return !pretty_name.isEmpty (); }
+    void *role (RoleType msg, void *content=NULL);
     void closed ();
 };
 
-class Tracklist : public Element {
+class KMPLAYER_NO_EXPORT Tracklist : public Element {
 public:
     KDE_NO_CDTOR_EXPORT Tracklist (NodePtr & d) : Element (d, id_node_tracklist) {}
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "tracklist"; }
-    bool expose () const { return false; }
 };
 
-class KMPLAYER_NO_EXPORT Track : public Mrl {
+class KMPLAYER_NO_EXPORT Track : public Element {
 public:
-    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Mrl (d, id_node_track) {}
+    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Element (d, id_node_track) {}
     void closed ();
     void activate ();
-    PlayType playType ();
-    Mrl * linkNode ();
     KDE_NO_EXPORT const char * nodeName () const { return "track"; }
-    NodePtr childFromTag (const QString & tag);
-    NodePtrW location;
+    Node *childFromTag (const QString & tag);
 };
 
 class KMPLAYER_NO_EXPORT Location : public Mrl {
@@ -83,7 +79,6 @@ public:
     KDE_NO_CDTOR_EXPORT Location (NodePtr &d) : Mrl (d, id_node_location) {}
     KDE_NO_EXPORT const char * nodeName () const { return "location"; }
     void closed ();
-    bool expose () const { return false; }
 };
 
 } //namespace XSPF
