@@ -333,7 +333,7 @@ KDE_NO_EXPORT void KMPlayerPrefBroadcastFormatPage::slotIndexChanged (int index)
 }
 
 KDE_NO_EXPORT void KMPlayerPrefBroadcastFormatPage::slotTextChanged (const QString & txt) {
-    save->setEnabled (txt.length ());
+    save->setEnabled (txt.size ());
 }
 
 KDE_NO_EXPORT void KMPlayerPrefBroadcastFormatPage::slotItemHighlighted (int index) {
@@ -450,7 +450,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::sync (bool fromUI) {
         m_configpage->getSettings(ffserversettings);
     } else {
         m_configpage->setSettings (ffserversettings);
-        m_configpage->profile->setText (QString::null);
+        m_configpage->profile->setText (QString ());
     }
 }
 
@@ -494,7 +494,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     m_ffserver_process->setUseShell (true);
     connect (m_ffserver_process, SIGNAL (processExited (KProcess *)),
              this, SLOT (processStopped (KProcess *)));
-    QString conffile = locateLocal ("data", "kmplayer/ffserver.conf");
+    QString conffile = KStandardDirs::locateLocal ("data", "kmplayer/ffserver.conf");
     const char * noaudio = m_player->source ()->audioDevice ().isEmpty () ? "NoAudio" : "";
     FFServerSetting ffs;
     m_configpage->getSettings (ffs);
@@ -509,7 +509,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     QString configdata;
     QString buf;
     configdata.sprintf (ffserverconf, m_ffserverconfig->ffserverport, m_ffserverconfig->bindaddress.ascii (), m_ffserverconfig->maxclients, m_ffserverconfig->maxbandwidth, m_ffserverconfig->feedfile.ascii (), m_ffserverconfig->feedfilesize, ffs.format.ascii (), acl.ascii (), ffs.ffconfig (buf).ascii (), noaudio);
-    qfile.writeBlock (configdata.ascii (), configdata.length ());
+    qfile.writeBlock (configdata.ascii (), configdata.size ());
     qfile.close ();
     kdDebug () << configdata << endl;
     kdDebug () << "ffserver -f " << conffile << endl;
@@ -557,26 +557,26 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startFeed () {
     if (m_ffmpeg_process)
         m_ffmpeg_process->stop ();
     delete m_ffmpeg_process;
-    m_ffmpeg_process = new KMPlayer::FFMpeg (m_player, m_player->settings ());
+    m_ffmpeg_process = new KMPlayer::FFMpeg (m_player, NULL, m_player->settings ());
     connect (m_ffmpeg_process, SIGNAL (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)), this, SLOT (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)));
     ffurl.sprintf ("http://localhost:%d/kmplayer.ffm", m_ffserverconfig->ffserverport);
-    m_ffmpeg_process->setURL (KURL(ffurl));
-    if (!m_ffmpeg_process->play (m_player->source (), KMPlayer::NodePtr())) {
+    //m_ffmpeg_process->setUrl (KUrl(ffurl));
+    if (!m_ffmpeg_process->play ()) {
         KMessageBox::error (m_configpage, i18n ("Failed to start ffmpeg."), i18n ("Error"));
         stopProcess (m_ffserver_process);
         goto bail_out;
     }
-    if (m_ffmpeg_process->playing ()) {
+    if (m_ffmpeg_process->running ()) {
         m_ffserver_url.sprintf ("http://localhost:%d/video.%s", m_ffserverconfig->ffserverport, ffs.format.ascii ());
         m_endserver = false;
         m_configpage->feedled->setState (KLed::On);
-        m_player->openURL (KURL (m_ffserver_url));
+        m_player->openUrl (KUrl (m_ffserver_url));
     } else
         stopServer ();
 bail_out:
     m_configpage->setCursor (QCursor (Qt::ArrowCursor));
 }
-
+/*
 KDE_NO_EXPORT void KMPlayerBroadcastConfig::stateChange (KMPlayer::Process::State old, KMPlayer::Process::State state) {
     if (state < KMPlayer::Process::Buffering && old >KMPlayer::Process::Ready) {
         if (m_configpage)
@@ -593,7 +593,7 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::stateChange (KMPlayer::Process::Stat
         }
     }
 }
-
+*/
 KDE_NO_EXPORT void KMPlayerBroadcastConfig::processStopped (KProcess *) {
     kdDebug () << "ffserver process stopped" << endl;
     if (m_configpage) {
