@@ -30,7 +30,7 @@
 #include <qtimer.h>
 #include <qpair.h>
 #include <qpushbutton.h>
-#include <QMenu>
+#include <QStandardPaths>
 #include <qslider.h>
 #include <qfile.h>
 #include <qregexp.h>
@@ -45,15 +45,14 @@
 #include <kbookmark.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
-#include <ksimpleconfig.h>
+#include <kiconloader.h>
+#include <klocale.h>
 #include <kaction.h>
-#include <kstandarddirs.h>
 #include <kmimetype.h>
 #include <kprotocolinfo.h>
-#include <kauthorized.h>
 #include <kio/job.h>
 #include <kio/jobclasses.h>
-#include <kauthorized.h>
+#include <kurlauthorized.h>
 
 #include "kmplayerpartbase.h"
 #include "kmplayerview.h"
@@ -121,8 +120,8 @@ PartBase::PartBase (QWidget * wparent, QObject * parent, KSharedConfigPtr config
 {
     m_sources ["urlsource"] = new URLSource (this);
 
-    QString bmfile = KStandardDirs::locate ("data", "kmplayer/bookmarks.xml");
-    QString localbmfile = KStandardDirs::locateLocal ("data", "kmplayer/bookmarks.xml");
+    QString bmfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kmplayer/bookmarks.xml");
+    QString localbmfile = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kmplayer/bookmarks.xml";
     if (localbmfile != bmfile) {
         QProcess p;
         QStringList args;
@@ -152,7 +151,7 @@ KDE_NO_EXPORT void PartBase::showPlayListWindow () {
 
 KDE_NO_EXPORT void PartBase::addBookMark (const QString & t, const QString & url) {
     KBookmarkGroup b = m_bookmark_manager->root ();
-    b.addBookmark (t, KUrl (url));
+    b.addBookmark (t, KUrl (url), KIO::iconNameForUrl(url));
     m_bookmark_manager->emitChanged (b);
 }
 
@@ -162,7 +161,7 @@ void PartBase::init (KActionCollection * action_collection, const QString &objna
     connect(m_settings, SIGNAL(configChanged()), this, SLOT(settingsChanged()));
     m_settings->readConfig ();
     m_settings->applyColorSetting (false);
-    connect (m_view, SIGNAL (urlDropped (const KUrl::List &)), this, SLOT (openUrl (const KUrl::List &)));
+    connect (m_view, SIGNAL(urlDropped(const QList<QUrl>&)), this, SLOT(openUrl(const QList<QUrl>&)));
     connectPlaylist (m_view->playList ());
     connectInfoPanel (m_view->infoPanel ());
 
@@ -194,10 +193,10 @@ void PartBase::connectPanel (ControlPanel * panel) {
     connect (panel->hueSlider (), SIGNAL (valueChanged(int)), this, SLOT (hueValueChanged(int)));
     connect (panel->saturationSlider (), SIGNAL (valueChanged(int)), this, SLOT (saturationValueChanged(int)));*/
     connect (this, SIGNAL (languagesUpdated(const QStringList &, const QStringList &)), panel, SLOT (setLanguages (const QStringList &, const QStringList &)));
-    connect (panel->audioMenu, SIGNAL (activated (int)), this, SLOT (audioSelected (int)));
-    connect (panel->subtitleMenu, SIGNAL (activated (int)), this, SLOT (subtitleSelected (int)));
-    connect (this, SIGNAL (audioIsSelected (int)), panel, SLOT (selectAudioLanguage (int)));
-    connect (this, SIGNAL (subtitleIsSelected (int)), panel, SLOT (selectSubtitle (int)));
+    connect (panel->audioMenu, SIGNAL (triggered (QAction*)), this, SLOT (audioSelected (QAction*)));
+    connect (panel->subtitleMenu, SIGNAL (triggered (QAction*)), this, SLOT (subtitleSelected (QAction*)));
+    connect (panel->playerMenu, SIGNAL (triggered (QAction*)), this, SLOT (slotPlayerMenu (QAction*)));
+    connect (this, SIGNAL (panelActionToggled (QAction*)), panel, SLOT (actionToggled (QAction*)));
     connect (panel->fullscreenAction, SIGNAL (triggered (bool)),
             this, SLOT (fullScreen ()));
     connect (panel->configureAction, SIGNAL (triggered (bool)),
@@ -211,7 +210,7 @@ void PartBase::connectPanel (ControlPanel * panel) {
     //connect (panel (), SIGNAL (clicked ()), m_settings, SLOT (show ()));
 }
 
-void PartBase::createBookmarkMenu (KMenu *owner, KActionCollection *ac) {
+void PartBase::createBookmarkMenu(QMenu *owner, KActionCollection *ac) {
     m_bookmark_menu = new KBookmarkMenu (m_bookmark_manager, m_bookmark_owner, owner, ac);
 }
 
@@ -260,7 +259,7 @@ KDE_NO_EXPORT void PartBase::showControls (bool show) {
             show ? View::CP_Show : View::CP_Hide);
 }
 
-KDE_NO_EXPORT QString PartBase::getStatus () {
+QString PartBase::getStatus () {
     QString rval = "Waiting";
     if (source() && source()->document()) {
         if (source()->document()->unfinished ())
@@ -271,7 +270,7 @@ KDE_NO_EXPORT QString PartBase::getStatus () {
     return rval;
 }
 
-KDE_NO_EXPORT QString PartBase::doEvaluate (const QString &) {
+QString PartBase::doEvaluate (const QString &) {
     return "undefined";
 }
 
@@ -330,8 +329,8 @@ QString PartBase::processName (Mrl *mrl) {
         p.truncate (0);
         const MediaManager::ProcessInfoMap::const_iterator e = pinfos.constEnd();
         for (MediaManager::ProcessInfoMap::const_iterator i = pinfos.constBegin(); i != e; ++i)
-            if (i.data ()->supports (m_source->name ())) {
-                p = QString (i.data ()->name);
+            if (i.value ()->supports (m_source->name ())) {
+                p = QString (i.value ()->name);
                 break;
             }
     }
@@ -347,23 +346,23 @@ QString PartBase::processName (Mrl *mrl) {
 
 void PartBase::processCreated (Process*) {}
 
-KDE_NO_EXPORT void PartBase::slotPlayerMenu (int menu) {
+KDE_NO_EXPORT void PartBase::slotPlayerMenu (QAction* act) {
     Mrl *mrl = m_source->current ();
     bool playing = mrl && mrl->active ();
     const char * srcname = m_source->name ();
     QMenu *player_menu = m_view->controlPanel ()->playerMenu;
     MediaManager::ProcessInfoMap &pinfos = m_media_manager->processInfos ();
     const MediaManager::ProcessInfoMap::const_iterator e = pinfos.constEnd();
-    unsigned id = 0;
+    int id = 0;
     for (MediaManager::ProcessInfoMap::const_iterator i = pinfos.constBegin();
-            id < player_menu->count() && i != e;
+            id < player_menu->actions().count() && i != e;
             ++i) {
-        ProcessInfo *pinfo = i.data ();
+        ProcessInfo *pinfo = i.value ();
         if (!pinfo->supports (srcname))
             continue;
-        int menuid = player_menu->idAt (id);
-        player_menu->setItemChecked (menuid, menu == (int) id);
-        if (menuid == menu) {
+        QAction* menu = player_menu->actions().at (id);
+        menu->setChecked (menu == act);
+        if (menu == act) {
             if (strcmp (pinfo->name, "npp"))
                 m_settings->backends [srcname] = pinfo->name;
             temp_backends [srcname] = pinfo->name;
@@ -381,13 +380,13 @@ void PartBase::updatePlayerMenu (ControlPanel *panel, const QString &backend) {
     menu->clear ();
     MediaManager::ProcessInfoMap &pinfos = m_media_manager->processInfos ();
     const MediaManager::ProcessInfoMap::const_iterator e = pinfos.constEnd();
-    int id = 0; // if multiple parts, id's should be the same for all menu's
     for (MediaManager::ProcessInfoMap::const_iterator i = pinfos.constBegin(); i != e; ++i) {
-        ProcessInfo *p = i.data ();
+        ProcessInfo *p = i.value ();
         if (p->supports (m_source ? m_source->name () : "urlsource")) {
-            menu->insertItem (p->label, this, SLOT (slotPlayerMenu (int)), 0, id++);
+            QAction* act = menu->addAction (p->label);
+            act->setCheckable(true);
             if (backend == p->name)
-                menu->setItemChecked (id-1, true);
+                act->setChecked (true);
         }
     }
 }
@@ -468,6 +467,10 @@ qlonglong PartBase::length () const {
     return m_source ? m_source->length () : 0;
 }
 
+bool PartBase::openUrl (const QUrl &url) {
+    return openUrl(KUrl(url));
+}
+
 bool PartBase::openUrl (const KUrl &url) {
     kDebug () << "PartBase::openUrl " << url.url() << url.isValid ();
     if (!m_view) return false;
@@ -481,17 +484,17 @@ bool PartBase::openUrl (const KUrl &url) {
     return true;
 }
 
-bool PartBase::openUrl (const KUrl::List & urls) {
+bool PartBase::openUrl(const QList<QUrl>& urls) {
     if (urls.size () == 1) {
-        openUrl (urls[0]);
+        openUrl(KUrl(urls[0].toString()));
     } else {
         openUrl (KUrl ());
         NodePtr d = m_source->document ();
         if (d)
-            for (unsigned int i = 0; i < urls.size (); i++) {
+            for (int i = 0; i < urls.size (); i++) {
                 const KUrl &url = urls [i];
                 d->appendChild (new GenericURL (d,
-                            url.isLocalFile() ? url.toLocalFile() : url.url()));
+                            url.isLocalFile() ? url.toLocalFile() : url.toString()));
             }
     }
     return true;
@@ -532,7 +535,7 @@ void PartBase::timerEvent (QTimerEvent * e) {
     } else if (e->timerId () == m_rec_timer) {
         m_rec_timer = 0;
         if (m_record_doc)
-            openUrl (convertNode <RecordDocument> (m_record_doc)->record_file);
+            openUrl(KUrl(convertNode <RecordDocument> (m_record_doc)->record_file));
     }
     killTimer (e->timerId ());
 }
@@ -639,7 +642,7 @@ KDE_NO_EXPORT void PartBase::playListItemActivated(const QModelIndex &index) {
         QString src = ri->source;
         NodePtrW node = vi->node;
         //kDebug() << src << " " << vi->node->nodeName();
-        Source * source = src.isEmpty() ? m_source : m_sources[src.ascii()];
+        Source * source = src.isEmpty() ? m_source : m_sources[src.toAscii().constData()];
         if (node->isPlayable () || id_node_playlist_item == node->id) {
             source->play (node->mrl ()); //may become !isPlayable by lazy loading
             if (node && !node->isPlayable ())
@@ -703,12 +706,18 @@ void PartBase::setLanguages (const QStringList & al, const QStringList & sl) {
     emit languagesUpdated (al, sl);
 }
 
-KDE_NO_EXPORT void PartBase::audioSelected (int id) {
-    emit audioIsSelected (id);
+KDE_NO_EXPORT void PartBase::audioSelected (QAction* act) {
+    emit panelActionToggled(act);
+    int i = act->parentWidget()->actions().indexOf(act);
+    if (i >= 0)
+        emit audioIsSelected (i);
 }
 
-KDE_NO_EXPORT void PartBase::subtitleSelected (int id) {
-    emit subtitleIsSelected (id);
+KDE_NO_EXPORT void PartBase::subtitleSelected (QAction* act) {
+    emit panelActionToggled(act);
+    int i = act->parentWidget()->actions().indexOf(act);
+    if (i >= 0)
+        emit subtitleIsSelected (i);
 }
 
 void PartBase::recorderPlaying () {
@@ -720,7 +729,7 @@ void PartBase::recorderPlaying () {
 void PartBase::recorderStopped () {
     stopRecording ();
     if (m_view && m_rec_timer < 0 && m_record_doc)
-        openUrl (convertNode <RecordDocument> (m_record_doc)->record_file);
+        openUrl(KUrl(convertNode <RecordDocument> (m_record_doc)->record_file));
 }
 
 void PartBase::stopRecording () {
@@ -743,7 +752,7 @@ bool PartBase::isRecording ()
 
 void PartBase::record () {
     if (m_view) m_view->setCursor (QCursor (Qt::WaitCursor));
-    if (!m_view->controlPanel()->button(ControlPanel::button_record)->isOn ()) {
+    if (!m_view->controlPanel()->button(ControlPanel::button_record)->isChecked ()) {
         stopRecording ();
     } else {
         m_settings->show  ("RecordPage");
@@ -771,7 +780,7 @@ void PartBase::play () {
     if (!m_view)
         return;
     QPushButton *pb = ::qobject_cast <QPushButton *> (sender ());
-    if (pb && !pb->isOn ()) {
+    if (pb && !pb->isChecked ()) {
         stop ();
         return;
     }
@@ -817,7 +826,7 @@ bool PartBase::playing () const {
 void PartBase::stop () {
     QPushButton * b = m_view ? m_view->controlPanel ()->button (ControlPanel::button_stop) : 0L;
     if (b) {
-        if (!b->isOn ())
+        if (!b->isChecked ())
             b->toggle ();
         m_view->setCursor (QCursor (Qt::WaitCursor));
     }
@@ -826,14 +835,14 @@ void PartBase::stop () {
     MediaManager::ProcessInfoMap &pi = m_media_manager->processInfos ();
     const MediaManager::ProcessInfoMap::const_iterator ie = pi.constEnd();
     for (MediaManager::ProcessInfoMap::const_iterator i = pi.constBegin(); i != ie; ++i)
-        i.data ()->quitProcesses ();
+        i.value ()->quitProcesses ();
     MediaManager::ProcessList &processes = m_media_manager->processes ();
     const MediaManager::ProcessList::const_iterator e = processes.constEnd();
     for (MediaManager::ProcessList::const_iterator i = processes.constBegin(); i != e; ++i)
         (*i)->quit ();
     if (m_view) {
         m_view->setCursor (QCursor (Qt::ArrowCursor));
-        if (b->isOn ())
+        if (b->isChecked ())
             b->toggle ();
         m_view->controlPanel ()->setPlaying (false);
         setLoaded (100);
@@ -1002,9 +1011,9 @@ void *SourceDocument::role (RoleType msg, void *data) {
 }
 
 
-Source::Source (const QString & name, PartBase * player, const char * n)
- : QObject (player, n),
-   m_name (name), m_player (player),
+Source::Source (const QString&, PartBase * player, const char * n)
+ : QObject (player),
+   m_name (n), m_player (player),
    m_identified (false), m_auto_play (true), m_avoid_redirects (false),
    m_frequency (0), m_xvport (0), m_xvencoding (-1), m_doc_timer (0) {
     init ();
@@ -1084,6 +1093,8 @@ void Source::setAspect (NodePtr node, float a) {
         if (changed && m_player->view ())
             m_player->viewWidget ()->viewArea ()->resizeEvent (NULL);
 
+    } else {
+       mrl->message (MsgSurfaceBoundsUpdate);
     }
     if (changed)
         emit dimensionsChanged ();
@@ -1130,6 +1141,13 @@ void Source::setUrl (const QString &url) {
     }
     if (m_player->source () == this)
         m_player->updateTree ();
+
+    QTimer::singleShot (0, this, SLOT(changedUrl ()));
+}
+
+void Source::changedUrl()
+{
+    emit titleChanged (this->prettyName ());
 }
 
 void Source::setTitle (const QString & title) {
@@ -1142,9 +1160,7 @@ KDE_NO_EXPORT void Source::setAudioLang (int id) {
         id--;
     m_audio_id = li ? li->id : -1;
     if (m_player->view () && m_player->mediaManager ()->processes ().size ())
-        m_player->mediaManager ()->processes ().first ()->setAudioLang (
-             m_audio_id,
-             m_player->viewWidget ()->controlPanel ()->audioMenu->text (id));
+        m_player->mediaManager ()->processes ().first ()->setAudioLang (m_audio_id);
 }
 
 KDE_NO_EXPORT void Source::setSubtitle (int id) {
@@ -1153,9 +1169,7 @@ KDE_NO_EXPORT void Source::setSubtitle (int id) {
         id--;
     m_subtitle_id = li ? li->id : -1;
     if (m_player->view () && m_player->mediaManager ()->processes ().size ())
-        m_player->mediaManager ()->processes ().first ()->setSubtitle (
-             m_subtitle_id,
-             m_player->viewWidget ()->controlPanel ()->subtitleMenu->text (id));
+        m_player->mediaManager ()->processes ().first ()->setSubtitle (m_subtitle_id);
 }
 
 void Source::reset () {
@@ -1519,11 +1533,14 @@ QString URLSource::prettyName () {
     if (m_url.isEmpty ())
         return i18n ("URL");
     if (m_url.url ().size () > 50) {
-        QString newurl = m_url.protocol () + QString ("://");
-        if (m_url.hasHost ())
-            newurl += m_url.host ();
-        if (m_url.port ())
-            newurl += QString (":%1").arg (m_url.port ());
+        QString newurl;
+        if (!m_url.isLocalFile ()) {
+            newurl = m_url.protocol () + QString ("://");
+            if (m_url.hasHost ())
+                newurl += m_url.host ();
+            if (m_url.port () != -1)
+                newurl += QString (":%1").arg (m_url.port ());
+        }
         QString file = m_url.fileName ();
         int len = newurl.size () + file.size ();
         KUrl path = KUrl (m_url.directory ());
@@ -1538,9 +1555,11 @@ QString URLSource::prettyName () {
         if (modified)
             dir += QString (".../");
         newurl += dir + file;
-        return i18n ("Url - ") + newurl;
+        return i18n ("URL - ") + newurl;
     }
-    return i18n ("Url - ") + m_url.prettyUrl ();
+    if (m_url.isLocalFile())
+        return i18n ("URL - ") + m_url.toLocalFile();
+    return i18n ("URL - ") + m_url.prettyUrl ();
 }
 
 bool URLSource::authoriseUrl (const QString &url) {
@@ -1556,7 +1575,7 @@ bool URLSource::authoriseUrl (const QString &url) {
 #else
             dest.isLocalFile () &&
 #endif
-                !KAuthorized::authorizeUrlAction ("redirect", base, dest)) {
+                !KUrlAuthorized::authorizeUrlAction ("redirect", base, dest)) {
             kWarning () << "requestPlayURL from document " << base << " to play " << dest << " is not allowed";
             return false;
         }
@@ -1577,4 +1596,3 @@ void URLSource::setUrl (const QString &url) {
 //-----------------------------------------------------------------------------
 
 #include "kmplayerpartbase.moc"
-#include "kmplayersource.moc"
