@@ -21,19 +21,21 @@
 
 #include <qtextstream.h>
 #include <kdebug.h>
-#include <kurl.h>
 #ifdef KMPLAYER_WITH_EXPAT
 #include <expat.h>
 #endif
 #include "kmplayerplaylist.h"
 #include "kmplayer_asx.h"
 #include "kmplayer_atom.h"
+#include "kmplayer_opml.h"
 #include "kmplayer_rp.h"
 #include "kmplayer_rss.h"
 #include "kmplayer_smil.h"
 #include "kmplayer_xspf.h"
 #include "mediaobject.h"
 
+#include <kurl.h>
+
 #ifdef SHAREDPTR_DEBUG
 KMPLAYER_EXPORT int shared_data_count;
 #endif
@@ -57,6 +59,8 @@ Node *KMPlayer::fromXMLDocumentTag (NodePtr & d, const QString & tag) {
         return new ATOM::Feed (d);
     else if (!strcasecmp (name, "playlist"))
         return new XSPF::Playlist (d);
+    else if (!strcasecmp (name, "opml"))
+        return new OPML::Opml (d);
     else if (!strcasecmp (name, "url"))
         return new GenericURL (d, QString ());
     else if (!strcasecmp (name, "mrl") ||
@@ -368,7 +372,7 @@ void TreeNode<Node>::appendChild (Node *c) {
 }
 
 template <>
-KDE_NO_EXPORT void TreeNode<Node>::insertBefore (Node *c, Node *b) {
+void TreeNode<Node>::insertBefore (Node *c, Node *b) {
     ASSERT (!c->parentNode ());
     static_cast <Node *> (this)->document()->m_tree_version++;
     insertBeforeImpl (c, b);
@@ -579,7 +583,7 @@ KDE_NO_CDTOR_EXPORT ElementPrivate::~ElementPrivate () {
 KDE_NO_EXPORT void ElementPrivate::clear () {
     const ParamMap::iterator e = params.end ();
     for (ParamMap::iterator i = params.begin (); i != e; ++i)
-        delete i.data ();
+        delete i.value ();
     params.clear ();
 }
 
@@ -1452,7 +1456,7 @@ bool DocumentBuilder::startTag(const QString &tag, const AttributeList &attr) {
     } else {
         NodePtr n = m_node->childFromTag (tag);
         if (!n) {
-            kDebug () << "Warning: unknown tag " << tag.latin1 ();
+            kDebug () << "Warning: unknown tag " << tag.toLocal8Bit ().constData();
             NodePtr doc = m_root->document ();
             n = new DarkNode (doc, tag.toUtf8 ());
         }
@@ -1499,7 +1503,7 @@ bool DocumentBuilder::endTag (const QString & tag) {
                     kError () << "m_node == m_doc, stack underflow " << endl;
                     return false;
                 }
-                kWarning () << "endtag: no match " << tag.local8Bit ();
+                kWarning () << "endtag: no match " << tag.toLocal8Bit ().constData();
                 break;
             } else
                  kWarning () << "tag " << tag << " not " << n->nodeName ();
