@@ -25,7 +25,7 @@
 #include <qfileinfo.h>
 #include <qtimer.h>
 #include <qlayout.h>
-#include <q3table.h>
+#include <qtablewidget.h>
 #include <qlineedit.h>
 #include <qslider.h>
 #include <qcombobox.h>
@@ -38,6 +38,7 @@
 #include <QtDBus/QtDBus>
 #include <QtCore/QDir>
 #include <QtCore/QUrl>
+#include <QHeaderView>
 #include <QNetworkCookie>
 
 #include <kdebug.h>
@@ -56,7 +57,6 @@
 #include "kmplayerview.h"
 #include "kmplayercontrolpanel.h"
 #include "kmplayerprocess.h"
-#include "kmplayersource.h"
 #include "kmplayerpartbase.h"
 #include "masteradaptor.h"
 #include "streammasteradaptor.h"
@@ -159,24 +159,22 @@ static void outputToView (View *view, const QByteArray &ba)
         view->addText (QString::fromLocal8Bit (ba.constData ()));
 }
 
-Process::Process (QObject *parent, ProcessInfo *pinfo, Settings *settings, const char * n)
- : QObject (parent, n),
+Process::Process (QObject *parent, ProcessInfo *pinfo, Settings *settings)
+ : QObject (parent),
    IProcess (pinfo),
    m_source (0L),
    m_settings (settings),
    m_old_state (IProcess::NotRunning),
    m_process (0L),
    m_job(0L),
-   m_process_state (QProcess::NotRunning) {
-    kDebug() << "new Process " << name () << endl;
-}
+   m_process_state (QProcess::NotRunning)
+{}
 
 Process::~Process () {
     quit ();
     delete m_process;
     if (user)
         user->processDestroyed (this);
-    kDebug() << "~Process " << name () << endl;
 }
 
 void Process::init () {
@@ -210,9 +208,9 @@ bool Process::running () const {
     return processRunning (m_process);
 }
 
-void Process::setAudioLang (int, const QString &) {}
+void Process::setAudioLang (int) {}
 
-void Process::setSubtitle (int, const QString &) {}
+void Process::setSubtitle (int) {}
 
 void Process::pause () {
 }
@@ -397,8 +395,8 @@ static bool proxyForURL (const KUrl &url, QString &proxy) {
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_CDTOR_EXPORT MPlayerBase::MPlayerBase (QObject *parent, ProcessInfo *pinfo, Settings * settings, const char * n)
-    : Process (parent, pinfo, settings, n),
+KDE_NO_CDTOR_EXPORT MPlayerBase::MPlayerBase (QObject *parent, ProcessInfo *pinfo, Settings * settings)
+    : Process (parent, pinfo, settings),
       m_needs_restarted (false) {
     m_process = new QProcess;
 }
@@ -424,8 +422,9 @@ KDE_NO_EXPORT void MPlayerBase::initProcess () {
 }
 
 bool MPlayerBase::removeQueued (const char *cmd) {
-    const QList<QByteArray>::iterator e = commands.end ();
-    for (QList<QByteArray>::iterator i = commands.begin (); i != e; ++i)
+    for (QList<QByteArray>::iterator i = commands.begin ();
+            i != commands.end ();
+            ++i)
         if (!strncmp ((*i).data (), cmd, strlen (cmd))) {
             commands.erase (i);
             return true;
@@ -502,7 +501,7 @@ IProcess *MPlayerProcessInfo::create (PartBase *part, ProcessUser *usr) {
 
 KDE_NO_CDTOR_EXPORT
 MPlayer::MPlayer (QObject *parent, ProcessInfo *pinfo, Settings *settings)
- : MPlayerBase (parent, pinfo, settings, "mplayer"),
+ : MPlayerBase (parent, pinfo, settings),
    m_widget (0L),
    m_transition_state (NotRunning),
    aid (-1), sid (-1)
@@ -605,7 +604,7 @@ KDE_NO_EXPORT bool MPlayer::deMediafiedPlay () {
             break;
         QString plops = static_cast<Element *>(n)->getAttribute ("mplayeropts");
         if (!plops.isNull ()) {
-            QStringList sl = QStringList::split (QChar (' '), plops);
+            QStringList sl = plops.split (QChar (' '));
             for (int i = 0; i < sl.size (); ++i)
                 args << sl[i];
             break;
@@ -618,7 +617,7 @@ KDE_NO_EXPORT bool MPlayer::deMediafiedPlay () {
     if (!url.isEmpty ()) {
         if (m_source->url ().isLocalFile ())
             m_process->setWorkingDirectory
-                (QFileInfo (m_source->url ().path ()).dirPath (true));
+                (QFileInfo (m_source->url ().path ()).absolutePath ());
         if (url.isLocalFile ()) {
             m_url = url.toLocalFile ();
             if (cfg_page->alwaysbuildindex &&
@@ -688,8 +687,7 @@ KDE_NO_EXPORT bool MPlayer::seek (int pos, bool absolute) {
         return false;
     if (m_request_seek >= 0 && commands.size () > 1) {
         QList<QByteArray>::iterator i = commands.begin ();
-        QList<QByteArray>::iterator end ( commands.end () );
-        for (++i; i != end; ++i)
+        for (++i; i != commands.end (); ++i)
             if (!strncmp ((*i).data (), "seek", 4)) {
                 i = commands.erase (i);
                 m_request_seek = -1;
@@ -814,7 +812,7 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
         if (process_stats) {
             QRegExp & m_posRegExp = patterns[MPlayerPreferencesPage::pat_pos];
             QRegExp & m_cacheRegExp = patterns[MPlayerPreferencesPage::pat_cache];
-            if (m_posRegExp.search (out) > -1) {
+            if (m_posRegExp.indexIn (out) > -1) {
                 if (m_source->hasLength ()) {
                     int pos = int (10.0 * m_posRegExp.cap (1).toFloat ());
                     m_source->setPosition (pos);
@@ -824,11 +822,11 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
                     m_transition_state = NotRunning;
                     setState (Playing);
                 }
-            } else if (m_cacheRegExp.search (out) > -1) {
+            } else if (m_cacheRegExp.indexIn (out) > -1) {
                 m_source->setLoading (int (m_cacheRegExp.cap(1).toDouble()));
             }
         } else if (out.startsWith ("ID_LENGTH")) {
-            int pos = out.find ('=');
+            int pos = out.indexOf ('=');
             if (pos > 0) {
                 int l = (int) out.mid (pos + 1).toDouble (&ok);
                 if (ok && l >= 0) {
@@ -840,7 +838,7 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
                 m_transition_state = NotRunning;
                 setState (Paused);
             }
-        } else if (m_refURLRegExp.search(out) > -1) {
+        } else if (m_refURLRegExp.indexIn(out) > -1) {
             kDebug () << "Reference mrl " << m_refURLRegExp.cap (1);
             if (!m_tmpURL.isEmpty () &&
                     (m_url.endsWith (m_tmpURL) || m_tmpURL.endsWith (m_url)))
@@ -850,23 +848,23 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
             if (m_source->url () == m_tmpURL ||
                     m_url.endsWith (m_tmpURL) || m_tmpURL.endsWith (m_url))
                 m_tmpURL.truncate (0);
-        } else if (m_refRegExp.search (out) > -1) {
+        } else if (m_refRegExp.indexIn (out) > -1) {
             kDebug () << "Reference File ";
             m_tmpURL.truncate (0);
         } else if (out.startsWith ("ID_VIDEO_WIDTH")) {
-            int pos = out.find ('=');
+            int pos = out.indexOf ('=');
             if (pos > 0) {
                 int w = out.mid (pos + 1).toInt ();
                 m_source->setDimensions (mrl (), w, m_source->height ());
             }
         } else if (out.startsWith ("ID_VIDEO_HEIGHT")) {
-            int pos = out.find ('=');
+            int pos = out.indexOf ('=');
             if (pos > 0) {
                 int h = out.mid (pos + 1).toInt ();
                 m_source->setDimensions (mrl (), m_source->width (), h);
             }
         } else if (out.startsWith ("ID_VIDEO_ASPECT")) {
-            int pos = out.find ('=');
+            int pos = out.indexOf ('=');
             if (pos > 0) {
                 bool ok;
                 QString val = out.mid (pos + 1);
@@ -879,10 +877,10 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
                     m_source->setAspect (mrl (), a);
             }
         } else if (out.startsWith ("ID_AID_")) {
-            int pos = out.find ('_', 7);
+            int pos = out.indexOf ('_', 7);
             if (pos > 0) {
                 int id = out.mid (7, pos - 7).toInt ();
-                pos = out.find ('=', pos);
+                pos = out.indexOf ('=', pos);
                 if (pos > 0) {
                     if (!alanglist_end) {
                         alanglist = new Source::LangInfo (id, out.mid (pos + 1));
@@ -895,10 +893,10 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
                 }
             }
         } else if (out.startsWith ("ID_SID_")) {
-            int pos = out.find ('_', 7);
+            int pos = out.indexOf ('_', 7);
             if (pos > 0) {
                 int id = out.mid (7, pos - 7).toInt ();
-                pos = out.find ('=', pos);
+                pos = out.indexOf ('=', pos);
                 if (pos > 0) {
                     if (!slanglist_end) {
                         slanglist = new Source::LangInfo (id, out.mid (pos + 1));
@@ -911,10 +909,10 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
                 }
             }
         } else if (out.startsWith ("ICY Info")) {
-            int p = out.find ("StreamTitle=", 8);
+            int p = out.indexOf ("StreamTitle=", 8);
             if (p > -1) {
                 p += 12;
-                int e = out.find (';', p);
+                int e = out.indexOf (';', p);
                 if (e > -1)
                     e -= p;
                 QString inf = out.mid (p, e);
@@ -926,20 +924,21 @@ KDE_NO_EXPORT void MPlayer::processOutput () {
             v->addText (out, true);
             if (!m_source->processOutput (out)) {
                 // int movie_width = m_source->width ();
-                if (/*movie_width <= 0 &&*/ m_sizeRegExp.search (out) > -1) {
+                if (/*movie_width <= 0 &&*/ m_sizeRegExp.indexIn (out) > -1) {
                     int movie_width = m_sizeRegExp.cap (1).toInt (&ok);
                     int movie_height = ok ? m_sizeRegExp.cap (2).toInt (&ok) : 0;
                     if (ok && movie_width > 0 && movie_height > 0) {
                         m_source->setDimensions(mrl(),movie_width,movie_height);
                         m_source->setAspect (mrl(), 1.0*movie_width/movie_height);
                     }
-                } else if (m_startRegExp.search (out) > -1) {
+                } else if (m_startRegExp.indexIn (out) > -1) {
                     if (!m_tmpURL.isEmpty () && m_url != m_tmpURL) {
                         m_source->insertURL (mrl (), m_tmpURL);;
                         m_tmpURL.truncate (0);
                     }
                     m_source->setIdentified ();
                     m_source->setLanguages (alanglist, slanglist);
+                    m_source->setLoading (100);
                     setState (IProcess::Playing);
                     m_source->setPosition (0);
                 }
@@ -985,13 +984,13 @@ KDE_NO_EXPORT void MPlayer::processStopped () {
     setState (IProcess::Ready);
 }
 
-void MPlayer::setAudioLang (int id, const QString &) {
+void MPlayer::setAudioLang (int id) {
     aid = id;
     m_needs_restarted = true;
     sendCommand (QString ("quit"));
 }
 
-void MPlayer::setSubtitle (int id, const QString &) {
+void MPlayer::setSubtitle (int id) {
     sid = id;
     m_needs_restarted = true;
     sendCommand (QString ("quit"));
@@ -1028,7 +1027,7 @@ namespace KMPlayer {
 class KMPLAYER_NO_EXPORT MPlayerPreferencesFrame : public QFrame {
 public:
     MPlayerPreferencesFrame (QWidget * parent);
-    Q3Table * table;
+    QTableWidget * table;
 };
 
 } // namespace
@@ -1036,30 +1035,33 @@ public:
 KDE_NO_CDTOR_EXPORT MPlayerPreferencesFrame::MPlayerPreferencesFrame (QWidget * parent)
  : QFrame (parent) {
     QVBoxLayout * layout = new QVBoxLayout (this);
-    table = new Q3Table (int (MPlayerPreferencesPage::pat_last)+non_patterns, 2, this);
-    table->verticalHeader ()->hide ();
-    table->setLeftMargin (0);
-    table->horizontalHeader ()->hide ();
-    table->setTopMargin (0);
-    table->setColumnReadOnly (0, true);
-    table->setText (0, 0, i18n ("MPlayer command:"));
-    table->setText (1, 0, i18n ("Additional command line arguments:"));
-    table->setText (2, 0, QString("%1 (%2)").arg (i18n ("Cache size:")).arg (i18n ("kB"))); // FIXME for new translations
-    table->setCellWidget (2, 1, new QSpinBox (0, 32767, 32, table->viewport()));
-    table->setText (3, 0, i18n ("Build new index when possible"));
+    table = new QTableWidget (int (MPlayerPreferencesPage::pat_last)+non_patterns, 2, this);
+    table->verticalHeader ()->setVisible (false);
+    table->horizontalHeader ()->setVisible (false);
+    table->setContentsMargins (0, 0, 0, 0);
+    table->setItem (0, 0, new QTableWidgetItem (i18n ("MPlayer command:")));
+    table->setItem (0, 1, new QTableWidgetItem ());
+    table->setItem (1, 0, new QTableWidgetItem (i18n ("Additional command line arguments:")));
+    table->setItem (1, 1, new QTableWidgetItem ());
+    table->setItem (2, 0, new QTableWidgetItem (QString("%1 (%2)").arg (i18n ("Cache size:")).arg (i18n ("kB")))); // FIXME for new translations
+    QSpinBox* spin = new QSpinBox(table->viewport());
+    spin->setMaximum(32767);
+    spin->setSingleStep(32);
+    table->setCellWidget (2, 1, spin);
+    table->setItem (3, 0, new QTableWidgetItem (i18n ("Build new index when possible")));
     table->setCellWidget (3, 1, new QCheckBox (table->viewport()));
-    QWhatsThis::add (table->cellWidget (3, 1), i18n ("Allows seeking in indexed files (AVIs)"));
-    for (int i = 0; i < int (MPlayerPreferencesPage::pat_last); i++)
-        table->setText (i+non_patterns, 0, _mplayer_patterns[i].caption);
-    QFontMetrics metrics (table->font ());
-    int first_column_width = 50;
-    for (int i = 0; i < int (MPlayerPreferencesPage::pat_last+non_patterns); i++) {
-        int strwidth = metrics.boundingRect (table->text (i, 0)).width ();
-        if (strwidth > first_column_width)
-            first_column_width = strwidth + 4;
+    table->cellWidget (3, 1)->setWhatsThis(i18n ("Allows seeking in indexed files (AVIs)"));
+    for (int i = 0; i < int (MPlayerPreferencesPage::pat_last); i++) {
+        table->setItem (i+non_patterns, 0, new QTableWidgetItem (_mplayer_patterns[i].caption));
+        table->setItem (i+non_patterns, 1, new QTableWidgetItem ());
     }
-    table->setColumnWidth (0, first_column_width);
-    table->setColumnStretchable (1, true);
+    for (int i = 0; i < non_patterns + int (MPlayerPreferencesPage::pat_last); i++) {
+        QTableWidgetItem *item = table->itemAt (i, 0);
+        item->setFlags (item->flags () ^ Qt::ItemIsEditable);
+    }
+    table->horizontalHeader ()->setResizeMode (QHeaderView::ResizeToContents);
+    table->horizontalHeader ()->setStretchLastSection (true);
+    table->resizeRowsToContents ();
     layout->addWidget (table);
 }
 
@@ -1092,21 +1094,21 @@ KDE_NO_EXPORT void MPlayerPreferencesPage::read (KSharedConfigPtr config) {
 }
 
 KDE_NO_EXPORT void MPlayerPreferencesPage::sync (bool fromUI) {
-    Q3Table * table = m_configframe->table;
+    QTableWidget * table = m_configframe->table;
     QSpinBox * cacheSize = static_cast<QSpinBox *>(table->cellWidget (2, 1));
     QCheckBox * buildIndex = static_cast<QCheckBox *>(table->cellWidget (3, 1));
     if (fromUI) {
-        mplayer_path = table->text (0, 1);
-        additionalarguments = table->text (1, 1);
+        mplayer_path = table->item (0, 1)->text ();
+        additionalarguments = table->item (1, 1)->text ();
         for (int i = 0; i < int (pat_last); i++)
-            m_patterns[i].setPattern (table->text (i+non_patterns, 1));
+            m_patterns[i].setPattern (table->item (i+non_patterns, 1)->text ());
         cachesize = cacheSize->value();
         alwaysbuildindex = buildIndex->isChecked ();
     } else {
-        table->setText (0, 1, mplayer_path);
-        table->setText (1, 1, additionalarguments);
+        table->item (0, 1)->setText (mplayer_path);
+        table->item (1, 1)->setText (additionalarguments);
         for (int i = 0; i < int (pat_last); i++)
-            table->setText (i+non_patterns, 1, m_patterns[i].pattern ());
+            table->item (i+non_patterns, 1)->setText (m_patterns[i].pattern ());
         if (cachesize > 0)
             cacheSize->setValue(cachesize);
         buildIndex->setChecked (alwaysbuildindex);
@@ -1145,7 +1147,7 @@ IProcess *MEncoderProcessInfo::create (PartBase *part, ProcessUser *usr) {
 
 KDE_NO_CDTOR_EXPORT
 MEncoder::MEncoder (QObject * parent, ProcessInfo *pinfo, Settings * settings)
- : MPlayerBase (parent, pinfo, settings, "mencoder") {}
+ : MPlayerBase (parent, pinfo, settings) {}
 
 KDE_NO_CDTOR_EXPORT MEncoder::~MEncoder () {
 }
@@ -1211,7 +1213,7 @@ IProcess *MPlayerDumpProcessInfo::create (PartBase *p, ProcessUser *usr) {
 
 KDE_NO_CDTOR_EXPORT
 MPlayerDumpstream::MPlayerDumpstream (QObject *p, ProcessInfo *pi, Settings *s)
- : MPlayerBase (p, pi, s, "mplayerdumpstream") {}
+ : MPlayerBase (p, pi, s) {}
 
 KDE_NO_CDTOR_EXPORT MPlayerDumpstream::~MPlayerDumpstream () {
 }
@@ -1325,8 +1327,8 @@ void MasterProcessInfo::slaveOutput () {
     outputToView(manager->player()->viewWidget(), m_slave->readAllStandardError ());
 }
 
-MasterProcess::MasterProcess (QObject *parent, ProcessInfo *pinfo, Settings *settings, const char *n)
- : Process (parent, pinfo, settings, n) {}
+MasterProcess::MasterProcess (QObject *parent, ProcessInfo *pinfo, Settings *settings)
+ : Process (parent, pinfo, settings) {}
 
 MasterProcess::~MasterProcess () {
 }
@@ -1484,7 +1486,7 @@ bool PhononProcessInfo::startSlave () {
 }
 
 Phonon::Phonon (QObject *parent, ProcessInfo *pinfo, Settings *settings)
- : MasterProcess (parent, pinfo, settings, "phonon") {}
+ : MasterProcess (parent, pinfo, settings) {}
 
 bool Phonon::ready () {
     if (user && user->viewer ())
@@ -1550,9 +1552,13 @@ QWidget * TypeNode::createWidget (QWidget * parent) {
     const char *ctype = ba.constData ();
     QString value = getAttribute (Ids::attr_value);
     if (!strcmp (ctype, "range")) {
-        w = new QSlider (getAttribute (QString ("START")).toInt (),
-                getAttribute (Ids::attr_end).toInt (),
-                1, value.toInt (), Qt::Horizontal, parent);
+        QSlider* slider = new QSlider (parent);
+        slider->setMinimum(getAttribute (QString ("START")).toInt ());
+        slider->setMaximum(getAttribute (Ids::attr_end).toInt ());
+        slider->setPageStep(1);
+        slider->setOrientation(Qt::Horizontal);
+        slider->setValue(value.toInt ());
+        w = slider;
     } else if (!strcmp (ctype, "num") || !strcmp (ctype,  "string")) {
         w = new QLineEdit (value, parent);
     } else if (!strcmp (ctype, "bool")) {
@@ -1563,8 +1569,8 @@ QWidget * TypeNode::createWidget (QWidget * parent) {
         QComboBox * combo = new QComboBox (parent);
         for (Node *e = firstChild (); e; e = e->nextSibling ())
             if (e->isElementNode () && !strcmp (e->nodeName (), "item"))
-                combo->insertItem (static_cast <Element *> (e)->getAttribute (Ids::attr_value));
-        combo->setCurrentItem (value.toInt ());
+                combo->addItem (static_cast <Element *> (e)->getAttribute (Ids::attr_value));
+        combo->setCurrentIndex (value.toInt ());
         w = combo;
     } else if (!strcmp (ctype, "tree")) {
     } else
@@ -1585,7 +1591,7 @@ void TypeNode::changedXML (QTextStream & out) {
     } else if (!strcmp (ctype, "bool")) {
         newvalue = QString::number (static_cast <QCheckBox *> (w)->isChecked());
     } else if (!strcmp (ctype, "enum")) {
-        newvalue = QString::number (static_cast<QComboBox *>(w)->currentItem());
+        newvalue = QString::number (static_cast<QComboBox *>(w)->currentIndex());
     } else if (!strcmp (ctype, "tree")) {
     } else
         kDebug() << "Unknown type:" << ctype;
@@ -1614,7 +1620,7 @@ IProcess *FFMpegProcessInfo::create (PartBase *p, ProcessUser *usr) {
 }
 
 FFMpeg::FFMpeg (QObject *parent, ProcessInfo *pinfo, Settings * settings)
- : Process (parent, pinfo, settings, "ffmpeg") {
+ : Process (parent, pinfo, settings) {
 }
 
 KDE_NO_CDTOR_EXPORT FFMpeg::~FFMpeg () {
@@ -1796,8 +1802,8 @@ KDE_NO_EXPORT void NpStream::open () {
                 this, SLOT (slotData (KIO::Job *, const QByteArray &)));
         connect (job, SIGNAL (result (KJob *)),
                 this, SLOT (slotResult (KJob *)));
-        connect (job, SIGNAL (redirection (KIO::Job *, const KUrl &)),
-                this, SLOT (redirection (KIO::Job *, const KUrl &)));
+        connect (job, SIGNAL(redirection(KIO::Job*, const QUrl&)),
+                this, SLOT (redirection (KIO::Job *, const QUrl &)));
         connect (job, SIGNAL (mimetype (KIO::Job *, const QString &)),
                 SLOT (slotMimetype (KIO::Job *, const QString &)));
         connect (job, SIGNAL (totalSize (KJob *, qulonglong)),
@@ -1851,13 +1857,13 @@ KDE_NO_EXPORT void NpStream::slotData (KIO::Job*, const QByteArray& qb) {
     }
 }
 
-KDE_NO_EXPORT void NpStream::redirection (KIO::Job *, const KUrl &kurl) {
+KDE_NO_EXPORT void NpStream::redirection (KIO::Job*, const QUrl& kurl) {
     url = kurl.url ();
     emit redirected (stream_id, kurl);
 }
 
 void NpStream::slotMimetype (KIO::Job *, const QString &mime) {
-    mimetype = mime;
+    mimetype = mime.indexOf("adobe.flash") > -1 ? "application/x-shockwave-flash" : mime;
 }
 
 void NpStream::slotTotalSize (KJob *, qulonglong sz) {
@@ -1866,7 +1872,7 @@ void NpStream::slotTotalSize (KJob *, qulonglong sz) {
 
 KDE_NO_CDTOR_EXPORT
 NpPlayer::NpPlayer (QObject *parent, ProcessInfo *pinfo, Settings *settings)
- : Process (parent, pinfo, settings, "npp"),
+ : Process (parent, pinfo, settings),
    write_in_progress (false),
    in_process_stream (false) {
 }
@@ -1902,7 +1908,6 @@ KDE_NO_EXPORT void NpPlayer::initProcess () {
 KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
     kDebug() << "NpPlayer::play '" << m_url << "' state " << m_state;
     // if we change from XPLAIN to XEMBED, the DestroyNotify may come later
-    Mrl *node = mrl ();
     if (!view ())
         return false;
     if (!m_url.isEmpty () && m_url != "about:empty") {
@@ -1969,6 +1974,8 @@ KDE_NO_EXPORT bool NpPlayer::ready () {
                 kDebug() << "search plugin " << mrl->mimetype << "->" << plugin;
                 if (!plugin.isEmpty ()) {
                     mime = mrl->mimetype;
+                    if ( mime.indexOf("adobe.flash") > -1 )
+                        mime = "application/x-shockwave-flash";
                     break;
                 }
             }
@@ -2010,7 +2017,7 @@ static int getStreamId (const QString &path) {
         return -1;
     }
     bool ok;
-    Q_UINT32 sid = path.mid (p+1).toInt (&ok);
+    qint32 sid = path.mid (p+1).toInt (&ok);
     if (!ok) {
         kError() << "wrong object path suffix " << path.mid (p+1) << endl;
         return -1;
@@ -2027,7 +2034,7 @@ KDE_NO_EXPORT void NpPlayer::request_stream (const QString &path, const QString
         uri = KUrl (base.isEmpty () ? m_url : base, url).url ();
     }
     kDebug () << "NpPlayer::request " << path << " '" << uri << "'" << m_url << "->" << url;
-    Q_UINT32 sid = getStreamId (path);
+    qint32 sid = getStreamId (path);
     if ((int)sid >= 0) {
         if (!target.isEmpty ()) {
             kDebug () << "new page request " << target;
@@ -2080,7 +2087,7 @@ KDE_NO_EXPORT void NpPlayer::destroyStream (uint32_t sid) {
 }
 
 KDE_NO_EXPORT
-void NpPlayer::sendFinish (Q_UINT32 sid, Q_UINT32 bytes, NpStream::Reason because) {
+void NpPlayer::sendFinish (quint32 sid, quint32 bytes, NpStream::Reason because) {
     kDebug() << "NpPlayer::sendFinish " << sid << " bytes:" << bytes;
     if (running ()) {
         uint32_t reason = (int) because;
@@ -2099,7 +2106,7 @@ KDE_NO_EXPORT void NpPlayer::terminateJobs () {
     Process::terminateJobs ();
     const StreamMap::iterator e = streams.end ();
     for (StreamMap::iterator i = streams.begin (); i != e; ++i)
-        delete i.data ();
+        delete i.value ();
     streams.clear ();
 }
 
@@ -2138,7 +2145,7 @@ KDE_NO_EXPORT void NpPlayer::streamStateChanged () {
         processStreams ();
 }
 
-KDE_NO_EXPORT void NpPlayer::streamRedirected (uint32_t sid, const KUrl &u) {
+KDE_NO_EXPORT void NpPlayer::streamRedirected(uint32_t sid, const QUrl& u) {
     if (running ()) {
         kDebug() << "redirected " << sid << " to " << u.url();
         QString objpath = QString ("/stream_%1").arg (sid);
@@ -2186,7 +2193,7 @@ KDE_NO_EXPORT void NpPlayer::requestCall (const uint32_t id, const QString &func
 
 KDE_NO_EXPORT void NpPlayer::processStreams () {
     NpStream *stream = 0L;
-    Q_UINT32 stream_id;
+    qint32 stream_id;
     timeval tv = { 0x7fffffff, 0 };
     const StreamMap::iterator e = streams.end ();
     int active_count = 0;
@@ -2199,7 +2206,7 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
 
     //kDebug() << "NpPlayer::processStreams " << streams.size ();
     for (StreamMap::iterator i = streams.begin (); i != e;) {
-        NpStream *ns = i.data ();
+        NpStream *ns = i.value ();
         if (ns->job) {
             active_count++;
         } else if (active_count < 5 &&
@@ -2208,8 +2215,8 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
             ns->open ();
             write_in_progress = false;
             if (ns->job) {
-                connect (ns, SIGNAL (redirected (uint32_t, const KUrl&)),
-                        this, SLOT (streamRedirected (uint32_t, const KUrl&)));
+                connect(ns, SIGNAL(redirected(uint32_t, const QUrl&)),
+                        this, SLOT(streamRedirected(uint32_t, const QUrl&)));
                 active_count++;
             }
         }
@@ -2247,11 +2254,11 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
             msg.setDelayedReply (false);
             QDBusConnection::sessionBus().send (msg);
         }
-        const int header_len = 2 * sizeof (Q_UINT32);
-        Q_UINT32 chunk = stream->pending_buf.size ();
+        const int header_len = 2 * sizeof (qint32);
+        qint32 chunk = stream->pending_buf.size ();
         send_buf.resize (chunk + header_len);
-        memcpy (send_buf.data (), &stream_id, sizeof (Q_UINT32));
-        memcpy (send_buf.data() + sizeof (Q_UINT32), &chunk, sizeof (Q_UINT32));
+        memcpy (send_buf.data (), &stream_id, sizeof (qint32));
+        memcpy (send_buf.data() + sizeof (qint32), &chunk, sizeof (qint32));
         memcpy (send_buf.data ()+header_len,
                 stream->pending_buf.constData (), chunk);
         stream->pending_buf = QByteArray ();
@@ -2265,7 +2272,7 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
     in_process_stream = false;
 }
 
-KDE_NO_EXPORT void NpPlayer::wroteStdin (qint64 sz) {
+KDE_NO_EXPORT void NpPlayer::wroteStdin (qint64) {
     if (!m_process->bytesToWrite ()) {
         write_in_progress = false;
         if (running ())
@@ -2296,13 +2303,13 @@ KDE_NO_CDTOR_EXPORT NpStream::NpStream (NpPlayer *p, uint32_t sid, const QString
 KDE_NO_CDTOR_EXPORT NpStream::~NpStream () {}
 void NpStream::slotResult (KJob*) {}
 void NpStream::slotData (KIO::Job*, const QByteArray&) {}
-void NpStream::redirection (KIO::Job *, const KUrl &) {}
+void NpStream::redirection(KIO::Job*, const QUrl&) {}
 void NpStream::slotMimetype (KIO::Job *, const QString &) {}
 void NpStream::slotTotalSize (KJob *, KIO::filesize_t) {}
 
 KDE_NO_CDTOR_EXPORT
 NpPlayer::NpPlayer (QObject *parent, ProcessInfo *pinfo, Settings *settings)
- : Process (parent, pinfo, settings, "npp") {}
+ : Process (parent, pinfo, settings) {}
 KDE_NO_CDTOR_EXPORT NpPlayer::~NpPlayer () {}
 KDE_NO_EXPORT void NpPlayer::init () {}
 KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () { return false; }
@@ -2316,7 +2323,7 @@ KDE_NO_EXPORT void NpPlayer::processOutput () {}
 KDE_NO_EXPORT void NpPlayer::processStopped (int, QProcess::ExitStatus) {}
 KDE_NO_EXPORT void NpPlayer::wroteStdin (qint64) {}
 KDE_NO_EXPORT void NpPlayer::streamStateChanged () {}
-KDE_NO_EXPORT void NpPlayer::streamRedirected (uint32_t, const KUrl &) {}
+KDE_NO_EXPORT void NpPlayer::streamRedirected(uint32_t, const QUrl&) {}
 KDE_NO_EXPORT void NpPlayer::terminateJobs () {}
 
 #endif
