@@ -29,12 +29,11 @@
 #include <qregexp.h>
 #include <qprocess.h>
 
-#include <kurl.h>
 #include <kio/global.h>
 
 #include "kmplayer_def.h"
 #include "kmplayerplaylist.h"
-#include "kmplayersource.h"
+#include "kmplayerpartbase.h"
 #include "mediaobject.h"
 
 class QWidget;
@@ -66,13 +65,13 @@ class XMLPreferencesFrame;
 class KMPLAYER_EXPORT Process : public QObject, public IProcess {
     Q_OBJECT
 public:
-    Process (QObject *parent, ProcessInfo *, Settings *settings, const char *n);
+    Process (QObject *parent, ProcessInfo *, Settings *settings);
     virtual ~Process ();
 
     virtual void init ();
     virtual void initProcess ();
-    virtual void setAudioLang (int, const QString &);
-    virtual void setSubtitle (int, const QString &);
+    virtual void setAudioLang (int id);
+    virtual void setSubtitle (int id);
     virtual bool running () const;
     KDE_NO_EXPORT QProcess * process () const { return m_process; }
     KDE_NO_EXPORT Source * source () const { return m_source; }
@@ -80,7 +79,7 @@ public:
     WId widget ();
     void setSource (Source * src) { m_source = src; }
     void setState (IProcess::State newstate);
-    virtual bool grabPicture (const QString &file, int frame);
+    virtual bool grabPicture (const QString &file, int frame) KDE_NO_EXPORT;
     Mrl *mrl () const;
 
     virtual bool ready ();
@@ -88,6 +87,7 @@ public:
     virtual void stop ();
     virtual void quit ();
     virtual void pause ();
+    virtual void unpause ();
     /* seek (pos, abs) seek position in deci-seconds */
     virtual bool seek (int pos, bool absolute);
     /* volume from 0 to 100 */
@@ -100,7 +100,7 @@ public:
 signals:
     void grabReady (const QString & path);
 protected slots:
-    void rescheduledStateChanged ();
+    void rescheduledStateChanged () KDE_NO_EXPORT;
     void result (KJob *);
     void processStateChanged (QProcess::ProcessState);
 protected:
@@ -125,20 +125,21 @@ protected:
 class MPlayerBase : public Process {
     Q_OBJECT
 public:
-    MPlayerBase (QObject *parent, ProcessInfo *, Settings *, const char *);
+    MPlayerBase (QObject *parent, ProcessInfo *, Settings *);
     ~MPlayerBase ();
-    void initProcess ();
-    virtual void stop ();
-    virtual void quit ();
+    void initProcess () KDE_NO_EXPORT;
+    virtual void stop () KDE_NO_EXPORT;
+    virtual void quit () KDE_NO_EXPORT;
 protected:
-    bool sendCommand (const QString &);
+    bool sendCommand (const QString &) KDE_NO_EXPORT;
+    bool removeQueued (const char *cmd);
     QList<QByteArray> commands;
     bool m_needs_restarted;
 protected slots:
-    virtual void processStopped ();
+    virtual void processStopped () KDE_NO_EXPORT;
 private slots:
-    void dataWritten (qint64);
-    void processStopped (int, QProcess::ExitStatus);
+    void dataWritten (qint64) KDE_NO_EXPORT;
+    void processStopped (int, QProcess::ExitStatus) KDE_NO_EXPORT;
 };
 
 /*
@@ -153,27 +154,28 @@ public:
 class KDE_EXPORT MPlayer : public MPlayerBase {
     Q_OBJECT
 public:
-    MPlayer (QObject *parent, ProcessInfo *pinfo, Settings *settings);
-    ~MPlayer ();
+    MPlayer (QObject *parent, ProcessInfo *pinfo, Settings *settings) KDE_NO_CDTOR_EXPORT;
+    ~MPlayer () KDE_NO_CDTOR_EXPORT;
 
-    virtual void init ();
-    virtual bool grabPicture (const QString &file, int pos);
-    virtual void setAudioLang (int, const QString &);
-    virtual void setSubtitle (int, const QString &);
-    virtual bool deMediafiedPlay ();
-    virtual void stop ();
-    virtual void pause ();
-    virtual bool seek (int pos, bool absolute);
-    virtual void volume (int pos, bool absolute);
-    virtual bool saturation (int pos, bool absolute);
-    virtual bool hue (int pos, bool absolute);
-    virtual bool contrast (int pos, bool absolute);
-    virtual bool brightness (int pos, bool absolute);
-    bool ready ();
+    virtual void init () KDE_NO_EXPORT;
+    virtual bool grabPicture (const QString &file, int pos) KDE_NO_EXPORT;
+    virtual void setAudioLang (int id);
+    virtual void setSubtitle (int id);
+    virtual bool deMediafiedPlay () KDE_NO_EXPORT;
+    virtual void stop () KDE_NO_EXPORT;
+    virtual void pause () KDE_NO_EXPORT;
+    virtual void unpause () KDE_NO_EXPORT;
+    virtual bool seek (int pos, bool absolute) KDE_NO_EXPORT;
+    virtual void volume (int pos, bool absolute) KDE_NO_EXPORT;
+    virtual bool saturation (int pos, bool absolute) KDE_NO_EXPORT;
+    virtual bool hue (int pos, bool absolute) KDE_NO_EXPORT;
+    virtual bool contrast (int pos, bool absolute) KDE_NO_EXPORT;
+    virtual bool brightness (int pos, bool absolute) KDE_NO_EXPORT;
+    bool ready () KDE_NO_EXPORT;
 protected:
-    void processStopped ();
+    void processStopped () KDE_NO_EXPORT;
 private slots:
-    void processOutput ();
+    void processOutput () KDE_NO_EXPORT;
 private:
     QString m_process_output;
     QString m_grab_file;
@@ -184,6 +186,7 @@ private:
     WeakPtr <Source::LangInfo> alanglist_end;
     Source::LangInfoPtr slanglist;
     WeakPtr <Source::LangInfo> slanglist_end;
+    State m_transition_state;
     int aid, sid;
     int old_volume;
 };
@@ -301,7 +304,7 @@ protected:
 class KMPLAYER_NO_EXPORT MasterProcess : public Process {
     Q_OBJECT
 public:
-    MasterProcess (QObject *p, ProcessInfo *pi, Settings *s, const char *n);
+    MasterProcess (QObject *p, ProcessInfo *pi, Settings *s);
     ~MasterProcess ();
 
     virtual void init ();
@@ -314,6 +317,7 @@ public:
     void playing ();
     void progress (uint64_t pos);
     void pause ();
+    void unpause ();
     bool seek (int pos, bool absolute);
     void volume (int pos, bool absolute);
     void eof ();
@@ -384,14 +388,14 @@ public:
 class KMPLAYER_EXPORT FFMpeg : public Process {
     Q_OBJECT
 public:
-    FFMpeg (QObject *parent, ProcessInfo *pinfo, Settings *settings);
-    ~FFMpeg ();
-    virtual void init ();
+    FFMpeg (QObject *parent, ProcessInfo *pinfo, Settings *settings) KDE_NO_CDTOR_EXPORT;
+    ~FFMpeg () KDE_NO_CDTOR_EXPORT;
+    virtual void init () KDE_NO_EXPORT;
     virtual bool deMediafiedPlay ();
-    virtual void stop ();
-    virtual void quit ();
+    virtual void stop () KDE_NO_EXPORT;
+    virtual void quit () KDE_NO_EXPORT;
 private slots:
-    void processStopped (int, QProcess::ExitStatus);
+    void processStopped (int, QProcess::ExitStatus) KDE_NO_EXPORT;
 };
 
 /*
@@ -424,13 +428,15 @@ public:
     uint32_t content_length;
     Reason finish_reason;
     QString mimetype;
+    QString http_headers;
+    bool received_data;
 signals:
     void stateChanged ();
-    void redirected (uint32_t, const KUrl &);
+    void redirected(uint32_t, const QUrl&);
 private slots:
     void slotResult (KJob*);
     void slotData (KIO::Job*, const QByteArray& qb);
-    void redirection (KIO::Job *, const KUrl &url);
+    void redirection(KIO::Job*, const QUrl& url);
     void slotMimetype (KIO::Job *, const QString &mime);
     void slotTotalSize (KJob *, qulonglong sz);
 };
@@ -460,6 +466,7 @@ public:
     void plugged () KMPLAYER_NO_MBR_EXPORT;
     void request_stream (const QString &path, const QString &url, const QString &target, const QByteArray &post) KMPLAYER_NO_MBR_EXPORT;
     QString evaluate (const QString &script, bool store) KMPLAYER_NO_MBR_EXPORT;
+    QString cookie (const QString &url);
     void dimension (int w, int h) KMPLAYER_NO_MBR_EXPORT;
 
     void destroyStream (uint32_t sid);
@@ -481,7 +488,7 @@ private slots:
     void processStopped (int, QProcess::ExitStatus);
     void wroteStdin (qint64);
     void streamStateChanged ();
-    void streamRedirected (uint32_t, const KUrl &);
+    void streamRedirected(uint32_t, const QUrl&);
 protected:
     virtual void terminateJobs ();
 private:
