@@ -30,21 +30,22 @@
 #include <qtextedit.h>
 #include <qtooltip.h>
 #include <qapplication.h>
-#include <qiconset.h>
 #include <qcursor.h>
 #include <qkeysequence.h>
 #include <qslider.h>
 #include <qlabel.h>
 #include <qdatastream.h>
 #include <QContextMenuEvent>
-#include <Q3TextDrag>
+#include <QMimeData>
 #include <QDropEvent>
 #include <QAction>
 #include <QDragEnterEvent>
+#include <QFontDatabase>
 #include <QTextDocument>
 #include <QTextCursor>
 #include <qcursor.h>
 #include <qclipboard.h>
+#include <kicon.h>
 #include <QMainWindow>
 #include <QDockWidget>
 
@@ -54,23 +55,15 @@
 #include <klocale.h>
 #include <kapplication.h>
 #include <kactioncollection.h>
-#include <kstdaction.h>
 #include <kshortcut.h>
 #include <kfinddialog.h>
-#include <kglobalsettings.h>
-#include <k3staticdeleter.h>
 
 #include "kmplayerview.h"
 #include "kmplayercontrolpanel.h"
-#include "kmplayersource.h"
 #include "playlistview.h"
 #include "viewarea.h"
 #include <solid/powermanagement.h>
 
-extern const char * normal_window_xpm[];
-extern const char * playlist_xpm[];
-
-
 /* mouse invisible: define the time (in 1/1000 seconds) before mouse goes invisible */
 
 
@@ -88,7 +81,7 @@ KDE_NO_EXPORT void PictureWidget::mousePressEvent (QMouseEvent *) {
 }
 
 KDE_NO_EXPORT void PictureWidget::mouseMoveEvent (QMouseEvent *e) {
-    if (e->state () == Qt::NoButton)
+    if (e->buttons () == Qt::NoButton)
         m_view->mouseMoved (e->x (), e->y ());
 }
 
@@ -97,6 +90,7 @@ KDE_NO_EXPORT void PictureWidget::mouseMoveEvent (QMouseEvent *e) {
 KDE_NO_CDTOR_EXPORT TextEdit::TextEdit (QWidget * parent, View * view) : QTextEdit (parent), m_view (view) {
 #if QT_VERSION > 0x040399
     setAttribute (Qt::WA_NativeWindow);
+    setAttribute(Qt::WA_DontCreateNativeAncestors);
 #endif
     setReadOnly (true);
     QPalette p=palette();
@@ -132,6 +126,7 @@ KDE_NO_CDTOR_EXPORT View::View (QWidget *parent)
     m_statusbar_mode (SB_Hide),
     controlbar_timer (0),
     infopanel_timer (0),
+    m_restore_state_timer(0),
     m_powerManagerStopSleep( -1 ),
     m_keepsizeratio (false),
     m_playing (false),
@@ -142,18 +137,17 @@ KDE_NO_CDTOR_EXPORT View::View (QWidget *parent)
 {
     setAttribute (Qt::WA_NoSystemBackground, true);
     setAutoFillBackground (false);
+    setAcceptDrops(true);
 }
 
 KDE_NO_EXPORT void View::dropEvent (QDropEvent * de) {
-    KUrl::List uris = KUrl::List::fromMimeData( de->mimeData() );
-    if (uris.isEmpty() && Q3TextDrag::canDecode (de)) {
-        QString text;
-        Q3TextDrag::decode (de, text);
-        uris.push_back (KURL (text));
+    QList<QUrl> uris = de->mimeData()->urls();
+    if (uris.isEmpty() || !uris[0].isValid()) {
+        QString text = de->mimeData()->text();
+        if (!text.isEmpty())
+            uris.push_back(QUrl::fromUserInput(text));
     }
     if (uris.size () > 0) {
-        for (int i = 0; i < uris.size (); i++)
-            uris [i] = QUrl::fromPercentEncoding (uris [i].url ().toUtf8 ());
         //m_widgetstack->currentWidget ()->setFocus ();
         emit urlDropped (uris);
         de->accept ();
@@ -167,6 +161,7 @@ KDE_NO_EXPORT void View::dragEnterEvent (QDragEnterEvent* dee) {
 
 void View::initDock (QWidget *central) {
     m_dockarea = new QMainWindow;
+    m_dockarea->setDockNestingEnabled(true);
     m_dockarea->setCentralWidget (central);
     central->setVisible (true);
 
@@ -204,19 +199,17 @@ KDE_NO_EXPORT void View::init (KActionCollection *action_collection, bool transp
     m_picture = new PictureWidget (m_view_area, this);
     m_picture->hide ();
     m_control_panel = new ControlPanel (m_view_area, this);
-    m_control_panel->setMaximumSize (2500, controlPanel ()->maximumSize ().height ());
+    m_control_panel->setMaximumHeight(controlPanel ()->maximumSize ().height ());
     m_status_bar = new StatusBar (m_view_area);
-    m_status_bar->insertItem (QString (""), 0);
-    m_status_bar->setItemAlignment (0, Qt::AlignLeft);
-    m_status_bar->setSizeGripEnabled (false);
+    m_status_bar->clearMessage();
     m_status_bar->setAutoFillBackground (true);
     QSize sbsize = m_status_bar->sizeHint ();
     m_status_bar->hide ();
-    m_status_bar->setMaximumSize (2500, sbsize.height ());
+    m_status_bar->setMaximumHeight(sbsize.height ());
     setVideoWidget (m_view_area);
 
     m_multiedit = new TextEdit (m_view_area, this);
-    QFont fnt = KGlobalSettings::fixedFont ();
+    QFont fnt = QFontDatabase::systemFont(QFontDatabase::FixedFont);
     m_multiedit->setFont (fnt);
     m_multiedit->hide ();
 
@@ -260,7 +253,7 @@ void View::setInfoMessage (const QString & msg) {
 
 void View::setStatusMessage (const QString & msg) {
     if (m_statusbar_mode != SB_Hide)
-        m_status_bar->changeItem (msg, 0);
+        m_status_bar->showMessage(msg);
 }
 
 void View::toggleShowPlaylist () {
@@ -319,7 +312,7 @@ bool View::setPicture (const QString & path) {
         if (m_image.isNull ())
             kDebug() << "View::setPicture failed " << path;
         else if (m_image.depth () < 24)
-            m_image = m_image.convertDepth (32, 0);
+            m_image = m_image.convertToFormat (QImage::Format_RGB32);
     }
     m_picture->setVisible (!m_image.isNull ());
     if (m_image.isNull ()) {
@@ -341,11 +334,11 @@ void View::toggleVideoConsoleWindow () {
     if (m_multiedit->isVisible ()) {
         m_multiedit->hide ();
         m_view_area->setVideoWidgetVisible (true);
-        m_control_panel->videoConsoleAction->setIcon (KIcon (("konsole")));
+        m_control_panel->videoConsoleAction->setIcon(QIcon::fromTheme(("konsole")));
         m_control_panel->videoConsoleAction->setText (i18n ("Con&sole"));
         delayedShowButtons (false);
     } else {
-        m_control_panel->videoConsoleAction->setIcon (KIcon ("video"));
+        m_control_panel->videoConsoleAction->setIcon(QIcon::fromTheme("video"));
         m_control_panel->videoConsoleAction->setText (i18n ("V&ideo"));
         m_multiedit->show ();
         m_multiedit->raise ();
@@ -417,7 +410,7 @@ KDE_NO_EXPORT void View::mouseMoved (int, int y) {
 
 KDE_NO_EXPORT void View::updateLayout () {
     if (m_controlpanel_mode == CP_Only)
-        m_control_panel->setMaximumSize (2500, height ());
+        m_control_panel->setMaximumHeight(height());
     m_view_area->resizeEvent (0L);
 }
 
@@ -454,6 +447,11 @@ KDE_NO_EXPORT void View::timerEvent (QTimerEvent * e) {
             m_dock_infopanel->hide ();
             //m_dock_infopanel->undock ();
         infopanel_timer  = 0;
+    } else if (e->timerId () == m_restore_state_timer) {
+        m_view_area->setVisible(true);
+        setControlPanelMode (m_old_controlpanel_mode);
+        m_dockarea->restoreState(m_dock_state);
+        m_restore_state_timer = 0;
     }
     killTimer (e->timerId ());
 }
@@ -500,7 +498,7 @@ KDE_NO_EXPORT void View::videoStart () {
         m_dockarea->setCentralWidget (m_view_area);
     }
     if (m_controlpanel_mode == CP_Only) {
-        m_control_panel->setMaximumSize(2500, controlPanel()->preferedHeight());
+        m_control_panel->setMaximumHeight(controlPanel()->preferredHeight());
         setControlPanelMode (CP_Show);
     }
 }
@@ -542,6 +540,10 @@ bool View::isFullScreen () const {
 }
 
 void View::fullScreen () {
+    if (m_restore_state_timer) {
+        killTimer (m_restore_state_timer);
+        m_restore_state_timer = 0;
+    }
     if (!m_view_area->isFullScreen()) {
         m_sreensaver_disabled = false;
         m_powerManagerStopSleep = Solid::PowerManagement::beginSuppressingSleep("KMplayer: watching a film");
@@ -558,6 +560,9 @@ void View::fullScreen () {
         }*/
         //if (m_keepsizeratio && m_viewer->aspect () < 0.01)
         //    m_viewer->setAspect (1.0 * m_viewer->width() / m_viewer->height());
+        m_dock_state = m_dockarea->saveState();
+        m_dock_playlist->hide();
+        m_dock_infopanel->hide();
         m_view_area->fullScreen();
         m_control_panel->zoomAction->setVisible (false);
         //if (m_viewer->isVisible ())
@@ -569,6 +574,7 @@ void View::fullScreen () {
        //         ("kdesktop", "KScreensaverIface", "enable(bool)", "true");
         m_view_area->fullScreen();
         m_control_panel->zoomAction->setVisible (true);
+        m_restore_state_timer = startTimer(100); //dockArea()->restoreState(m_dock_state);
     }
     setControlPanelMode (m_old_controlpanel_mode);
     emit fullScreenChanged ();
