@@ -23,20 +23,21 @@
 #include <qwidget.h>
 #include <qtextedit.h>
 #include <QImage>
+#include <QList>
+#include <QUrl>
 
-#include <kurl.h>
 #include <kmediaplayer/view.h>
 
-#include "kmplayersource.h"
+#include "kmplayer_def.h"
 
 #define MOUSE_INVISIBLE_DELAY 2000
 
 class QSlider;
+class QStatusBar;
 class QMainWindow;
 class QDockWidget;
 class KActionCollection;
 class KAction;
-class KStatusBar;
 
 namespace KMPlayer {
 
@@ -48,7 +49,7 @@ class PlayListView;
 class PlayListView;
 class TopPlayItem;
 
-typedef KStatusBar StatusBar;
+typedef QStatusBar StatusBar;
 
 /*
  * The console GUI
@@ -150,7 +151,7 @@ public slots:
     void setInfoMessage (const QString & msg);
     void setStatusMessage (const QString & msg);
 signals:
-    void urlDropped (const KUrl::List & urls);
+    void urlDropped (const QList<QUrl>& urls);
     void pictureClicked ();
     void fullScreenChanged ();
     void windowVideoConsoleToggled (bool show);
@@ -158,6 +159,7 @@ protected:
     void leaveEvent (QEvent *) KDE_NO_EXPORT;
     void timerEvent (QTimerEvent *) KDE_NO_EXPORT;
 private:
+    QByteArray m_dock_state;
     // console output
     TextEdit * m_multiedit;
     PictureWidget *m_picture;
@@ -179,6 +181,7 @@ private:
     StatusBarMode m_statusbar_mode;
     int controlbar_timer;
     int infopanel_timer;
+    int m_restore_state_timer;
     int m_powerManagerStopSleep;
     bool m_keepsizeratio;
     bool m_playing;
