@@ -22,7 +22,7 @@
 #include <qmovie.h>
 #include <QBuffer>
 #include <QPainter>
-#include <QSvgRenderer>
+#include <QtSvg/QSvgRenderer>
 #include <qimage.h>
 #include <qfile.h>
 #include <qurl.h>
@@ -35,14 +35,14 @@
 #include <kio/job.h>
 #include <kio/jobclasses.h>
 #include <kmimetype.h>
-#include <kauthorized.h>
+#include <kurlauthorized.h>
 
 #include "mediaobject.h"
-#include "kmplayerpartbase.h"
 #include "kmplayerprocess.h"
-#include "kmplayersource.h"
 #include "kmplayerview.h"
+#include "expression.h"
 #include "viewarea.h"
+#include "kmplayerpartbase.h"
 
 using namespace KMPlayer;
 
@@ -94,17 +94,15 @@ MediaManager::MediaManager (PartBase *player) : m_player (player) {
 }
 
 MediaManager::~MediaManager () {
-    const ProcessList::iterator e = m_processes.end ();
     for (ProcessList::iterator i = m_processes.begin ();
-            i != e;
+            i != m_processes.end ();
             i = m_processes.begin () /*~Process removes itself from this list*/)
     {
         kDebug() << "~MediaManager " << *i << endl;
         delete *i;
     }
-    const ProcessList::iterator re = m_recorders.end ();
     for (ProcessList::iterator i = m_recorders.begin ();
-            i != re;
+            i != m_recorders.end ();
             i = m_recorders.begin ())
     {
         kDebug() << "~MediaManager " << *i << endl;
@@ -113,11 +111,11 @@ MediaManager::~MediaManager () {
     const ProcessInfoMap::iterator ie = m_process_infos.end ();
     for (ProcessInfoMap::iterator i = m_process_infos.begin (); i != ie; ++i)
         if (!m_record_infos.contains (i.key ()))
-            delete i.data ();
+            delete i.value ();
 
     const ProcessInfoMap::iterator rie = m_record_infos.end ();
     for (ProcessInfoMap::iterator i = m_record_infos.begin (); i != rie; ++i)
-        delete i.data ();
+        delete i.value ();
 
     if (m_media_objects.size ()) {
         kError () << "~MediaManager media list not empty " << m_media_objects.size () << endl;
@@ -167,7 +165,7 @@ MediaObject *MediaManager::createAVMedia (Node *node, const QByteArray &) {
 }
 
 static const QString statemap [] = {
-    i18n ("Not Running"), i18n ("Ready"), i18n ("Buffering"), i18n ("Playing")
+    i18n ("Not Running"), i18n ("Ready"), i18n ("Buffering"), i18n ("Playing"),  i18n ("Paused")
 };
 
 void MediaManager::stateChange (AudioVideoMedia *media,
@@ -192,17 +190,11 @@ void MediaManager::stateChange (AudioVideoMedia *media,
     m_player->updateStatus (i18n ("Player %1 %2",
                 media->process->process_info->name, statemap[news]));
     if (IProcess::Playing == news) {
-        if (Element::state_deferred == mrl->state) {
-            media->ignore_pause = true;
+        if (Element::state_deferred == mrl->state)
             mrl->undefer ();
-            media->ignore_pause = false;
-        }
         bool has_video = !is_rec;
-        if (is_rec) {
-            const ProcessList::iterator i = m_recorders.find (media->process);
-            if (i != m_recorders.end ())
-                m_player->recorderPlaying ();
-        }
+        if (is_rec && m_recorders.contains(media->process))
+            m_player->recorderPlaying ();
         if (has_video) {
             if (m_player->view ()) {
                 if (media->viewer ()) {
@@ -239,7 +231,7 @@ void MediaManager::stateChange (AudioVideoMedia *media,
             }
             if (AudioVideoMedia::ask_delete == media->request) {
                 delete media;
-            } else if (olds > IProcess::Ready && mrl->unfinished ()) {
+            } else if (olds > IProcess::Ready) {
                 if (is_rec)
                     mrl->message (MsgMediaFinished, NULL); // FIXME
                 else
@@ -250,9 +242,7 @@ void MediaManager::stateChange (AudioVideoMedia *media,
         if (AudioVideoMedia::ask_pause == media->request) {
             media->pause ();
         } else if (mrl->view_mode != Mrl::SingleMode) {
-            media->ignore_pause = true;
             mrl->defer (); // paused the SMIL
-            media->ignore_pause = false;
         }
     }
 }
@@ -288,7 +278,7 @@ void MediaManager::processDestroyed (IProcess *process) {
 //------------------------%<----------------------------------------------------
 
 MediaObject::MediaObject (MediaManager *manager, Node *node)
- : m_manager (manager), m_node (node), paused (false) {
+ : m_manager (manager), m_node (node) {
     manager->medias ().push_back (this);
 }
 
@@ -308,17 +298,17 @@ Mrl *MediaObject::mrl () {
 
 void DataCache::add (const QString & url, const QString &mime, const QByteArray & data) {
     QByteArray bytes;
-    bytes.duplicate (data);
+    bytes = data;
     cache_map.insert (url, qMakePair (mime, bytes));
-    preserve_map.erase (url);
+    preserve_map.remove (url);
     emit preserveRemoved (url);
 }
 
 bool DataCache::get (const QString & url, QString &mime, QByteArray & data) {
     DataMap::const_iterator it = cache_map.constFind (url);
     if (it != cache_map.constEnd ()) {
-        mime = it.data ().first;
-        data = it.data ().second;
+        mime = it.value ().first;
+        data = it.value ().second;
         return true;
     }
     return false;
@@ -350,7 +340,7 @@ bool DataCache::unpreserve (const QString & url) {
 
 static bool isPlayListMime (const QString & mime) {
     QString m (mime);
-    int plugin_pos = m.find ("-plugin");
+    int plugin_pos = m.indexOf ("-plugin");
     if (plugin_pos > 0)
         m.truncate (plugin_pos);
     QByteArray ba = m.toAscii ();
@@ -393,7 +383,8 @@ static QString mimeByContent (const QByteArray &data)
 }
 
 MediaInfo::MediaInfo (Node *n, MediaManager::MediaType t)
- : media (NULL), type (t), node (n), job (NULL), preserve_wait (false) {
+ : media (NULL), type (t), node (n), job (NULL),
+    preserve_wait (false), check_access (false) {
 }
 
 MediaInfo::~MediaInfo () {
@@ -415,14 +406,14 @@ KDE_NO_EXPORT void MediaInfo::killWGet () {
 /**
  * Gets contents from url and puts it in m_data
  */
-KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
+KDE_NO_EXPORT bool MediaInfo::wget (const QString &str, const QString &domain) {
     clearData ();
     url = str;
 
     if (MediaManager::Any == type || MediaManager::Image == type) {
         ImageDataMap::iterator i = image_data_map->find (str);
         if (i != image_data_map->end ()) {
-            media = new ImageMedia (node, i.data ());
+            media = new ImageMedia (node, i.value ());
             type = MediaManager::Image;
             ready ();
             return true;
@@ -432,7 +423,8 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
     Mrl *mrl = node->mrl ();
     if (mrl && (MediaManager::Any == type || MediaManager::AudioVideo == type))
     {
-        mime = mrl->mimetype;
+        if (!mrl->mimetype.isEmpty ())
+            setMimetype (mrl->mimetype);
         if (mrl && (MediaManager::Any == type || MediaManager::AudioVideo == type))
             if (mime == "application/x-shockwave-flash" ||
                     mime == "application/futuresplash" ||
@@ -448,7 +440,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
             Mrl *m = p->mrl ();
             if (m && !m->src.isEmpty () &&
                   m->src != "Playlist://" &&
-                  !KAuthorized::authorizeUrlAction ("redirect", m->src, kurl)) {
+                  !KUrlAuthorized::authorizeUrlAction ("redirect", m->src, kurl)) {
                 kWarning () << "redirect access denied";
                 ready ();
                 return true;
@@ -457,7 +449,9 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
 
     bool only_playlist = false;
     bool maybe_playlist = false;
-    if (MediaManager::Audio == type || MediaManager::AudioVideo == type) {
+    if (MediaManager::Audio == type
+            || MediaManager::AudioVideo == type
+            || MediaManager::Any == type) {
         only_playlist = true;
         maybe_playlist = isPlayListMime (mime);
     }
@@ -470,18 +464,20 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
                 if (mrl && mimeptr) {
                     mrl->mimetype = mimeptr->name ();
                     setMimetype (mrl->mimetype);
-                    only_playlist = MediaManager::Audio == type ||
-                        MediaManager::AudioVideo == type;
-                    maybe_playlist = isPlayListMime (mime); // get new mime
                 }
                 kDebug () << "wget2 " << str << " " << mime;
+            } else {
+                setMimetype (mime);
             }
-            if (file.open (IO_ReadOnly)) {
+            only_playlist = MediaManager::Audio == type ||
+                MediaManager::AudioVideo == type;
+            maybe_playlist = isPlayListMime (mime); // get new mime
+            if (file.open (QIODevice::ReadOnly)) {
                 if (only_playlist) {
                     maybe_playlist &= file.size () < 2000000;
                     if (maybe_playlist) {
                         char databuf [512];
-                        int nr_bytes = file.readBlock (databuf, 512);
+                        int nr_bytes = file.read (databuf, 512);
                         if (nr_bytes > 3 &&
                                 (KMimeType::isBufferBinaryData (QByteArray (databuf, nr_bytes)) ||
                                  !strncmp (databuf, "RIFF", 4)))
@@ -501,15 +497,29 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
         return true;
     }
     QString protocol = kurl.protocol ();
-    if (MediaManager::Data != type &&
-            (memory_cache->get (str, mime, data) ||
-             protocol == "mms" || protocol == "rtsp" || protocol == "rtp" ||
-             (only_playlist && !maybe_playlist && !mime.isEmpty ()))) {
-        setMimetype (mime);
-        ready ();
-        return true;
+    if (!domain.isEmpty ()) {
+        QString get_from = protocol + "://" + kurl.host ();
+        if (get_from != domain) {
+            check_access = true;
+            access_from = domain;
+            cross_domain = get_from + "/crossdomain.xml";
+            kurl = KUrl (cross_domain);
+        }
     }
-    if (memory_cache->preserve (str)) {
+    if (!check_access) {
+        if (MediaManager::Data != type &&
+                (memory_cache->get (str, mime, data) ||
+                 protocol == "mms" || protocol == "rtsp" ||
+                 protocol == "rtp" || protocol == "rtmp" ||
+                 (only_playlist && !maybe_playlist && !mime.isEmpty ()))) {
+            setMimetype (mime);
+            if (MediaManager::Any == type)
+                type = MediaManager::AudioVideo;
+            ready ();
+            return true;
+        }
+    }
+    if (check_access || memory_cache->preserve (str)) {
         //kDebug () << "downloading " << str;
         job = KIO::get (kurl, KIO::NoReload, KIO::HideProgressInfo);
         job->addMetaData ("PropagateHttpHeader", "true");
@@ -518,8 +528,9 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
                 this, SLOT (slotData (KIO::Job *, const QByteArray &)));
         connect (job, SIGNAL (result (KJob *)),
                 this, SLOT (slotResult (KJob *)));
-        connect (job, SIGNAL (mimetype (KIO::Job *, const QString &)),
-                this, SLOT (slotMimetype (KIO::Job *, const QString &)));
+        if (!check_access)
+            connect (job, SIGNAL (mimetype (KIO::Job *, const QString &)),
+                    this, SLOT (slotMimetype (KIO::Job *, const QString &)));
     } else {
         //kDebug () << "download preserved " << str;
         connect (memory_cache, SIGNAL (preserveRemoved (const QString &)),
@@ -530,16 +541,16 @@ KDE_NO_EXPORT bool MediaInfo::wget (const QString &str) {
 }
 
 KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
-    QTextStream textstream (data, IO_ReadOnly);
+    QTextStream textstream (data, QIODevice::ReadOnly);
     QString line;
     NodePtr cur_elm = node;
     do {
         line = textstream.readLine ();
-    } while (!line.isNull () && line.stripWhiteSpace ().isEmpty ());
+    } while (!line.isNull () && line.trimmed ().isEmpty ());
     if (!line.isNull ()) {
         bool pls_groupfound =
             line.startsWith ("[") && line.endsWith ("]") &&
-            line.mid (1, line.size () - 2).stripWhiteSpace () == "playlist";
+            line.mid (1, line.size () - 2).trimmed () == "playlist";
         if ((pls_groupfound &&
                     cur_elm->mrl ()->mimetype.startsWith ("audio/")) ||
                 cur_elm->mrl ()->mimetype == QString ("audio/x-scpls")) {
@@ -548,10 +559,10 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                 QString url, title;
             } * entries = 0L;
             do {
-                line = line.stripWhiteSpace ();
+                line = line.trimmed ();
                 if (!line.isEmpty ()) {
                     if (line.startsWith ("[") && line.endsWith ("]")) {
-                        if (line.mid (1, line.size () - 2).stripWhiteSpace () == "playlist")
+                        if (line.mid (1, line.size () - 2).trimmed () == "playlist")
                             pls_groupfound = true;
                         else
                             break;
@@ -559,23 +570,23 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                     } else if (pls_groupfound) {
                         int eq_pos = line.indexOf (QChar ('='));
                         if (eq_pos > 0) {
-                            if (line.lower ().startsWith (QString ("numberofentries"))) {
-                                nr = line.mid (eq_pos + 1).stripWhiteSpace ().toInt ();
+                            if (line.toLower ().startsWith (QString ("numberofentries"))) {
+                                nr = line.mid (eq_pos + 1).trimmed ().toInt ();
                                 kDebug () << "numberofentries : " << nr;
                                 if (nr > 0 && nr < 1024)
                                     entries = new Entry[nr];
                                 else
                                     nr = 0;
                             } else if (nr > 0) {
-                                QString ll = line.lower ();
+                                QString ll = line.toLower ();
                                 if (ll.startsWith (QString ("file"))) {
                                     int i = line.mid (4, eq_pos-4).toInt ();
                                     if (i > 0 && i <= nr)
-                                        entries[i-1].url = line.mid (eq_pos + 1).stripWhiteSpace ();
+                                        entries[i-1].url = line.mid (eq_pos + 1).trimmed ();
                                 } else if (ll.startsWith (QString ("title"))) {
                                     int i = line.mid (5, eq_pos-5).toInt ();
                                     if (i > 0 && i <= nr)
-                                        entries[i-1].title = line.mid (eq_pos + 1).stripWhiteSpace ();
+                                        entries[i-1].title = line.mid (eq_pos + 1).trimmed ();
                                 }
                             }
                         }
@@ -590,10 +601,10 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                            QUrl::fromPercentEncoding (entries[i].url.toUtf8 ()),
                            entries[i].title));
             delete [] entries;
-        } else if (line.stripWhiteSpace ().startsWith (QChar ('<'))) {
+        } else if (line.trimmed ().startsWith (QChar ('<'))) {
             readXML (cur_elm, textstream, line);
             //cur_elm->normalize ();
-        } else if (line.lower () != QString ("[reference]")) {
+        } else if (line.toLower () != QString ("[reference]")) {
             bool extm3u = line.startsWith ("#EXTM3U");
             QString title;
             NodePtr doc = node->document ();
@@ -601,11 +612,11 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                 line = textstream.readLine ();
             while (!line.isNull ()) {
              /* TODO && m_document.size () < 1024 / * support 1k entries * /);*/
-                QString mrl = line.stripWhiteSpace ();
+                QString mrl = line.trimmed ();
                 if (line == QString ("--stop--"))
                     break;
-                if (mrl.lower ().startsWith (QString ("asf ")))
-                    mrl = mrl.mid (4).stripWhiteSpace ();
+                if (mrl.toLower ().startsWith (QString ("asf ")))
+                    mrl = mrl.mid (4).trimmed ();
                 if (!mrl.isEmpty ()) {
                     if (extm3u && mrl.startsWith (QChar ('#'))) {
                         if (line.startsWith ("#EXTINF:"))
@@ -627,6 +638,11 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
 void MediaInfo::setMimetype (const QString &mt)
 {
     mime = mt;
+
+    Mrl *mrl = node ? node->mrl () : NULL;
+    if (mrl && mrl->mimetype.isEmpty ())
+        mrl->mimetype = mt;
+
     if (MediaManager::Any == type) {
         if (mimetype ().startsWith ("image/"))
             type = MediaManager::Image;
@@ -651,6 +667,7 @@ KDE_NO_EXPORT void MediaInfo::clearData () {
     }
     url.truncate (0);
     mime.truncate (0);
+    access_from.truncate (0);
     data.resize (0);
 }
 
@@ -719,20 +736,53 @@ static bool validDataFormat (MediaManager::MediaType type, const QByteArray &ba)
 }
 
 KDE_NO_EXPORT void MediaInfo::slotResult (KJob *kjob) {
-    if (MediaManager::Data != type && !kjob->error ()) {
-        if (data.size () && data.size () < 512) {
-            setMimetype (mimeByContent (data));
-            if (!validDataFormat (type, data))
+    job = 0L; // signal KIO::Job::result deletes itself
+    if (check_access) {
+        check_access = false;
+
+        bool success = false;
+        if (!kjob->error () && data.size () > 0) {
+            QTextStream ts (data, QIODevice::ReadOnly);
+            NodePtr doc = new Document (QString ());
+            readXML (doc, ts, QString ());
+
+            Expression *expr = evaluateExpr (
+                    "//cross-domain-policy/allow-access-from/@domain");
+            if (expr) {
+                expr->setRoot (doc);
+                Expression::iterator it, e = expr->end();
+                for (it = expr->begin(); it != e; ++it) {
+                    QRegExp match (it->value(), Qt::CaseInsensitive, QRegExp::Wildcard);
+                    if (match.exactMatch (access_from)) {
+                        success = true;
+                        break;
+                    }
+                }
+                delete expr;
+            }
+            doc->document ()->dispose ();
+        }
+        if (success) {
+            wget (QString (url));
+        } else {
+            data.resize (0);
+            ready ();
+        }
+    } else {
+        if (MediaManager::Data != type && !kjob->error ()) {
+            if (data.size () && data.size () < 512) {
+                setMimetype (mimeByContent (data));
+                if (!validDataFormat (type, data))
+                    data.resize (0);
+            }
+            memory_cache->add (url, mime, data);
+        } else {
+            memory_cache->unpreserve (url);
+            if (MediaManager::Data != type)
                 data.resize (0);
         }
-        memory_cache->add (url, mime, data);
-    } else {
-        memory_cache->unpreserve (url);
-        if (MediaManager::Data != type)
-            data.resize (0);
+        ready ();
     }
-    job = 0L; // signal KIO::Job::result deletes itself
-    ready ();
 }
 
 KDE_NO_EXPORT void MediaInfo::cachePreserveRemoved (const QString & str) {
@@ -750,7 +800,7 @@ KDE_NO_EXPORT void MediaInfo::slotData (KIO::Job *, const QByteArray &qb) {
         int newsize = old_size + qb.size ();
         data.resize (newsize);
         memcpy (data.data () + old_size, qb.constData (), qb.size ());
-        if (old_size < 512 && newsize >= 512) {
+        if (!check_access && old_size < 512 && newsize >= 512) {
             setMimetype (mimeByContent (data));
             if (!validDataFormat (type, data)) {
                 data.resize (0);
@@ -792,8 +842,7 @@ AudioVideoMedia::AudioVideoMedia (MediaManager *manager, Node *node)
  : MediaObject (manager, node),
    process (NULL),
    m_viewer (NULL),
-   request (ask_nothing),
-   ignore_pause (false) {
+   request (ask_nothing) {
     kDebug() << "AudioVideoMedia::AudioVideoMedia" << endl;
 }
 
@@ -855,9 +904,8 @@ void AudioVideoMedia::stop () {
 }
 
 void AudioVideoMedia::pause () {
-    if (!ignore_pause && !paused && process) {
+    if (process) {
         if (process->state () > IProcess::Ready) {
-            paused = true;
             request = ask_nothing;
             process->pause ();
         } else {
@@ -867,12 +915,11 @@ void AudioVideoMedia::pause () {
 }
 
 void AudioVideoMedia::unpause () {
-    if (!ignore_pause && paused && process) {
+    if (process) {
         if (request == ask_pause) {
             request = ask_nothing;
         } else {
-            paused = false;
-            process->pause ();
+            process->unpause ();
         }
     }
 }
@@ -936,7 +983,7 @@ ImageData::ImageData( const QString & img)
 
 ImageData::~ImageData() {
     if (!url.isEmpty ())
-        image_data_map->erase (url);
+        image_data_map->remove (url);
 #ifdef KMPLAYER_WITH_CAIRO
     if (surface)
         cairo_surface_destroy (surface);
@@ -957,7 +1004,7 @@ void ImageData::setImage (QImage *img) {
         if (img) {
             width = img->width ();
             height = img->height ();
-            has_alpha = img->hasAlphaBuffer ();
+            has_alpha = img->hasAlphaChannel ();
         } else {
             width = height = 0;
         }
@@ -969,7 +1016,8 @@ ImageMedia::ImageMedia (MediaManager *manager, Node *node,
  : MediaObject (manager, node), data (ba), buffer (NULL),
    img_movie (NULL),
    svg_renderer (NULL),
-   update_render (false) {
+   update_render (false),
+   paused (false) {
     setupImage (url);
 }
 
@@ -987,6 +1035,9 @@ ImageMedia::ImageMedia (Node *node, ImageDataPtr id)
             if (svg_renderer->isValid ()) {
                 cached_img = new ImageData (QString ());
                 cached_img->flags = ImageData::ImageScalable;
+                if (svg_renderer->animated())
+                    connect(svg_renderer, SIGNAL(repaintNeeded()),
+                            this, SLOT(svgUpdated()));
             } else {
                 delete svg_renderer;
                 svg_renderer = NULL;
@@ -1018,19 +1069,27 @@ KDE_NO_EXPORT void ImageMedia::stop () {
 }
 
 void ImageMedia::pause () {
-    if (img_movie && !img_movie->state () == QMovie::Paused)
+    if (!paused && svg_renderer && svg_renderer->animated())
+        disconnect(svg_renderer, SIGNAL(repaintNeeded()),
+                this, SLOT(svgUpdated()));
+    if (img_movie && img_movie->state () != QMovie::Paused)
         img_movie->setPaused (true);
+    paused = true;
 }
 
 void ImageMedia::unpause () {
-    if (img_movie && img_movie->paused ())
+    if (paused && svg_renderer && svg_renderer->animated())
+        connect(svg_renderer, SIGNAL(repaintNeeded()),
+                this, SLOT(svgUpdated()));
+    if (img_movie && QMovie::Paused == img_movie->state ())
         img_movie->setPaused (false);
+    paused = false;
 }
 
 KDE_NO_EXPORT void ImageMedia::setupImage (const QString &url) {
     if (isEmpty () && data.size ()) {
-        QImage *pix = new QImage (data);
-        if (!pix->isNull ()) {
+        QImage *pix = new QImage;
+        if (pix->loadFromData((data))) {
             cached_img = ImageDataPtr (new ImageData (url));
             cached_img->setImage (pix);
         } else {
@@ -1113,6 +1172,12 @@ bool ImageMedia::isEmpty () const {
     return !cached_img || (!svg_renderer && cached_img->isEmpty ());
 }
 
+KDE_NO_EXPORT void ImageMedia::svgUpdated() {
+    cached_img->setImage (NULL);
+    if (m_node)
+        m_node->document ()->post (m_node, new Posting (m_node, MsgMediaUpdated));
+}
+
 KDE_NO_EXPORT void ImageMedia::movieResize (const QSize &) {
     //kDebug () << "movieResize" << endl;
     if (m_node)
@@ -1123,7 +1188,7 @@ KDE_NO_EXPORT void ImageMedia::movieUpdated (const QRect &) {
     if (frame_nr++) {
         ASSERT (cached_img && isEmpty ());
         QImage *img = new QImage;
-        *img = img_movie->framePixmap ();
+        *img = img_movie->currentImage ();
         cached_img->setImage (img);
         cached_img->flags = (int)(ImageData::ImagePixmap | ImageData::ImageAnimated); //TODO
         if (m_node)
@@ -1145,10 +1210,10 @@ TextMedia::TextMedia (MediaManager *manager, Node *node, const QByteArray &ba)
     QByteArray data (ba);
     if (!data [data.size () - 1])
         data.resize (data.size () - 1); // strip zero terminate char
-    QTextStream ts (data, IO_ReadOnly);
+    QTextStream ts (data, QIODevice::ReadOnly);
     QString val = convertNode <Element> (node)->getAttribute ("charset");
     if (!val.isEmpty ()) {
-        QTextCodec *codec = QTextCodec::codecForName (val.ascii ());
+        QTextCodec *codec = QTextCodec::codecForName (val.toAscii ());
         if (codec)
             ts.setCodec (codec);
     }
@@ -1159,7 +1224,7 @@ TextMedia::TextMedia (MediaManager *manager, Node *node, const QByteArray &ba)
         text = doc->innerText ();
         doc->dispose ();
     } else {
-        text = ts.read ();
+        text = ts.readAll ();
     }
 }
 
