@@ -32,7 +32,7 @@ extern "C" {
 #include <fcntl.h>
 
 #include <glib/gprintf.h>
-#include <glib/gthread.h>
+#include <glib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
@@ -128,11 +128,10 @@ static void dbusStreamUnregister (DBusConnection *conn, void *user_data);
 
 static void print (const char * format, ...) {
     va_list vl;
-    static FILE *out = stderr; //fopen ("/tmp/npp.out", "w+");
     va_start (vl, format);
-    vfprintf (out, format, vl);
+    vfprintf (stderr, format, vl);
     va_end (vl);
-    fflush (out);
+    fflush (stderr);
 }
 
 static void *nsAlloc (uint32 size) {
@@ -1043,7 +1042,7 @@ static bool windowClassInvoke (NPObject *npobj, NPIdentifier method,
     createJsName (jo, (char **)&str.utf8characters, &str.utf8length);
     pos = snprintf (buf, sizeof (buf), "%s.%s(", str.utf8characters, id);
     nsMemFree ((char *) str.utf8characters);
-    for (i = 0; i < arg_count; i++) {
+    for (i = 0; i < (int)arg_count; i++) {
         char *arg = nsVariant2Str (args + i);
         pos += snprintf (buf + pos,
                 sizeof (buf) - pos, i ? ",%s" : "%s", *arg ? arg : "undefined");
@@ -1055,7 +1054,7 @@ static bool windowClassInvoke (NPObject *npobj, NPIdentifier method,
     str.utf8length = pos;
     res = doEvaluate (npp, npobj, &str, result);
 
-    return true;
+    return res;
 }
 
 static bool windowClassInvokeDefault (NPObject *npobj,
@@ -1803,28 +1802,33 @@ static void pluginAdded (GtkSocket *socket, gpointer d) {
     callFunction (-1, iface_callback, "plugged", DBUS_TYPE_INVALID);
 }
 
+static gboolean pluginRemoved (GtkSocket *socket, gpointer d) {
+    (void)socket; (void)d;
+    return TRUE;
+}
+
 static void windowCreatedEvent (GtkWidget *w, gpointer d) {
     (void)d;
     print ("windowCreatedEvent\n");
     socket_id = gtk_socket_get_id (GTK_SOCKET (xembed));
     if (parent_id) {
         print ("windowCreatedEvent %p\n", GTK_PLUG (w)->socket_window);
-        if (!GTK_PLUG (w)->socket_window)
+        /*if (!GTK_PLUG (w)->socket_window)
             gtk_plug_construct (GTK_PLUG (w), parent_id);
-        /*gdk_window_reparent( w->window,
+        gdk_window_reparent( w->window,
                 GTK_PLUG (w)->socket_window
                     ? GTK_PLUG (w)->socket_window
                     : gdk_window_foreign_new (parent_id),
                 0, 0);*/
-        gtk_widget_show_all (w);
-        /*XReparentWindow (gdk_x11_drawable_get_xdisplay (w->window),
+        XReparentWindow (gdk_x11_drawable_get_xdisplay (w->window),
                 gdk_x11_drawable_get_xid (w->window),
                 parent_id,
-                0, 0);*/
+                0, 0);
+        gtk_widget_show_all (w);
     }
     if (!callback_service) {
-        char *argn[] = { "WIDTH", "HEIGHT", "debug", "SRC" };
-        char *argv[] = { "440", "330", g_strdup("yes"), g_strdup(object_url) };
+        char *argn[] = { g_strdup("WIDTH"), g_strdup("HEIGHT"), g_strdup("debug"), g_strdup("SRC") };
+        char *argv[] = { g_strdup("440"), g_strdup("330"), g_strdup("yes"), g_strdup(object_url) };
         if (startPlugin (mimetype, 4, argn, argv))
             addStream (object_url, mimetype, 0L, 0, NULL, 0L, false);
     }
@@ -1838,7 +1842,7 @@ static void embeddedEvent (GtkPlug *plug, gpointer d) {
 static gboolean updateDimension (void * p) {
     (void)p;
     if (np_window.window) {
-        if (np_window.width != top_w || np_window.height != top_h) {
+        if ((int)np_window.width != top_w || (int)np_window.height != top_h) {
             np_window.width = top_w;
             np_window.height = top_h;
             np_funcs.setwindow (npp, &np_window);
@@ -1885,9 +1889,9 @@ static gboolean initPlayer (void * p) {
     GdkColor bg_color;
     (void)p;
 
-    window = callback_service
+    window = /*callback_service
         ? gtk_plug_new (parent_id)
-        : gtk_window_new (GTK_WINDOW_TOPLEVEL);
+        :*/ gtk_window_new (GTK_WINDOW_TOPLEVEL);
     g_signal_connect (G_OBJECT (window), "delete_event",
             G_CALLBACK (windowCloseEvent), NULL);
     g_signal_connect (G_OBJECT (window), "destroy",
@@ -1900,6 +1904,8 @@ static gboolean initPlayer (void * p) {
     xembed = gtk_socket_new();
     g_signal_connect (G_OBJECT (xembed), "plug-added",
             GTK_SIGNAL_FUNC (pluginAdded), NULL);
+    g_signal_connect (G_OBJECT (xembed), "plug-removed",
+            GTK_SIGNAL_FUNC (pluginRemoved), NULL);
 
     color_map = gdk_colormap_get_system();
     gdk_colormap_query_color (color_map, 0, &bg_color);
