@@ -26,7 +26,6 @@
 #include "kmplayer_def.h"
 
 #include <kpagedialog.h>
-#include <kvbox.h>
 #include <qmap.h>
 
 #include "kmplayerplaylist.h"
@@ -34,15 +33,15 @@
 class QTabWidget;
 class QCheckBox;
 class QComboBox;
+class QLabel;
 class QLineEdit;
 class QRadioButton;
 class QSlider;
 class QSpinBox;
 class QColor;
-class Q3ButtonGroup;
-class Q3ListBox;
+class QButtonGroup;
+class QListWidget;
 class KHistoryCombo;
-class KIntSpinBox;
 class KComboBox;
 class KUrlRequester;
 class KColorButton;
@@ -60,7 +59,6 @@ class PrefFFMpegPage;           // ffmpeg
 class PrefXinePage;             // xine url:record
 class PrefGeneralPageLooks;     // general, looks
 class PrefGeneralPageOutput;	// general, output
-class PrefOPPageGeneral;	// OP = outputplugins, general
 class PrefOPPagePostProc;	// outputplugins, postproc
 class PartBase;
 class Source;
@@ -90,7 +88,6 @@ public:
     PrefFFMpegPage              *m_FFMpegPage;
     PrefGeneralPageLooks        *m_GeneralPageLooks;
     PrefGeneralPageOutput       *m_GeneralPageOutput;
-    PrefOPPageGeneral           *m_OPPageGeneral;
     PrefOPPagePostProc		*m_OPPagePostproc;
     void setDefaults();
     void setPage (const char *);
@@ -106,7 +103,7 @@ private:
     KPageWidgetItem *m_url_item;
 };
 
-class KMPLAYER_NO_EXPORT PrefGeneralPageGeneral : public KVBox
+class KMPLAYER_NO_EXPORT PrefGeneralPageGeneral : public QWidget
 {
     Q_OBJECT
 public:
@@ -115,7 +112,7 @@ public:
 
     QCheckBox *keepSizeRatio;
     QCheckBox * autoResize;
-    Q3ButtonGroup *sizesChoice;
+    QButtonGroup* sizesChoice;
     QCheckBox *dockSysTray;
     QCheckBox *loop;
     QCheckBox *showConfigButton;
@@ -126,10 +123,10 @@ public:
     QCheckBox *adjustvolume;
     QCheckBox *adjustcolors;
 
-    KIntSpinBox *seekTime;
+    QSpinBox *seekTime;
 };
 
-class KMPLAYER_NO_EXPORT PrefGeneralPageLooks : public KVBox {
+class KMPLAYER_NO_EXPORT PrefGeneralPageLooks : public QWidget {
     Q_OBJECT
 public:
     PrefGeneralPageLooks (QWidget *parent, Settings *);
@@ -148,7 +145,7 @@ private:
     FontSetting * fonts;
 };
 
-class KMPLAYER_NO_EXPORT PrefSourcePageURL : public KVBox
+class KMPLAYER_NO_EXPORT PrefSourcePageURL : public QWidget
 {
     Q_OBJECT
 public:
@@ -160,7 +157,7 @@ public:
     KComboBox * urllist;
     KUrlRequester * sub_url;
     KComboBox * sub_urllist;
-    Q3ListBox * backend;
+    QListWidget* backend;
     QCheckBox * clicktoplay;
     QCheckBox * grabhref;
     QLineEdit * prefBitRate;
@@ -172,7 +169,7 @@ private slots:
 };
 
 
-class KMPLAYER_NO_EXPORT PrefRecordPage : public KVBox
+class KMPLAYER_NO_EXPORT PrefRecordPage : public QWidget
 {
     Q_OBJECT
 public:
@@ -180,9 +177,9 @@ public:
     ~PrefRecordPage ();
 
     KUrlRequester * url;
-    Q3ButtonGroup * recorder;
-    Q3ButtonGroup * replay;
-    KIntSpinBox * replaytime;
+    QButtonGroup* recorder;
+    QButtonGroup* replay;
+    QSpinBox* replaytime;
     QLabel * source;
 protected:
     void showEvent (QShowEvent *);
@@ -200,7 +197,7 @@ private:
     int m_recorders_length;
 };
 
-class KMPLAYER_NO_EXPORT RecorderPage : public KVBox
+class KMPLAYER_NO_EXPORT RecorderPage : public QWidget
 {
     Q_OBJECT
 public:
@@ -226,7 +223,7 @@ public:
     const char * recorderName () { return "mencoder"; }
 
     QLineEdit * arguments;
-    Q3ButtonGroup * format;
+    QButtonGroup* format;
 public slots:
     void formatClicked (int id);
 private:
@@ -264,31 +261,23 @@ public:
     const char * recorderName () { return "ffmpeg"; }
 
     QLineEdit * arguments;
-    Q3ButtonGroup * format;
+    QButtonGroup* format;
 private:
 };
 
 
-class KMPLAYER_NO_EXPORT PrefGeneralPageOutput : public KVBox
+class KMPLAYER_NO_EXPORT PrefGeneralPageOutput : public QWidget
 {
     Q_OBJECT
 public:
     PrefGeneralPageOutput (QWidget *parent, OutputDriver * ad, OutputDriver * vd);
     ~PrefGeneralPageOutput() {}
 
-    Q3ListBox *videoDriver;
-    Q3ListBox *audioDriver;
+    QListWidget* videoDriver;
+    QListWidget* audioDriver;
 };
 
-class KMPLAYER_NO_EXPORT PrefOPPageGeneral : public KVBox
-{
-    Q_OBJECT
-public:
-    PrefOPPageGeneral(QWidget *parent = 0);
-    ~PrefOPPageGeneral() {}
-};
-
-class KMPLAYER_NO_EXPORT PrefOPPagePostProc : public KVBox
+class KMPLAYER_NO_EXPORT PrefOPPagePostProc : public QWidget
 {
     Q_OBJECT
 public:
