@@ -28,19 +28,19 @@
 #include <qmap.h>
 #include <QPalette>
 #include <QDesktopWidget>
-#include <QX11Info>
+#include <QtX11Extras/QX11Info>
 #include <QPainter>
 #include <QMainWindow>
 #include <QWidgetAction>
-#include <QtGui/QTextBlock>
-#include <QtGui/QTextDocument>
-#include <QtGui/QAbstractTextDocumentLayout>
-#include <QtGui/QImage>
+#include <QTextBlock>
+#include <QTextDocument>
+#include <QAbstractTextDocumentLayout>
+#include <QImage>
+#include <QAbstractNativeEventFilter>
 
 #include <kactioncollection.h>
 #include <kapplication.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
 #include <kshortcut.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -50,31 +50,19 @@
 #include "playlistview.h"
 #include "viewarea.h"
 #ifdef KMPLAYER_WITH_CAIRO
-# include <cairo-xlib.h>
-# include <cairo-xlib-xrender.h>
+# include <cairo-xcb.h>
 #endif
 #include "mediaobject.h"
 #include "kmplayer_smil.h"
 #include "kmplayer_rp.h"
 #include "mediaobject.h"
 
-#include <X11/Xlib.h>
-#include <X11/keysym.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-static const int XKeyPress = KeyPress;
-#undef KeyPress
-#undef Always
-#undef Never
-#undef Status
-#undef Unsorted
-#undef Bool
+#include <xcb/xcb.h>
+
+#include <kurl.h>
 
 using namespace KMPlayer;
 
-extern const char * normal_window_xpm[];
-extern const char * playlist_xpm[];
-
 //-------------------------------------------------------------------------
 
 #ifdef KMPLAYER_WITH_CAIRO
@@ -175,16 +163,28 @@ void ImageData::copyImage (Surface *s, const SSize &sz, cairo_surface_t *similar
             1.0 * (((c)) & 0xff) / 255,       \
             1.0 * (((c) >> 24) & 0xff) / 255)
 
-class KMPLAYER_NO_EXPORT CairoPaintVisitor : public Visitor {
-    IRect clip;
-    cairo_surface_t * cairo_surface;
+struct KMPLAYER_NO_EXPORT PaintContext
+{
+    PaintContext (const Matrix& m, const IRect& c)
+        : matrix (m)
+        , clip (c)
+        , fit (fit_default)
+        , bg_repeat (SMIL::RegionBase::BgRepeat)
+        , bg_image (NULL)
+    {}
     Matrix matrix;
+    IRect clip;
+    Fit fit;
+    SMIL::RegionBase::BackgroundRepeat bg_repeat;
+    ImageData *bg_image;
+};
+
+class KMPLAYER_NO_EXPORT CairoPaintVisitor : public Visitor, public PaintContext {
+    cairo_surface_t * cairo_surface;
     // stack vars need for transitions
     TransitionModule *cur_transition;
     cairo_pattern_t * cur_pat;
     cairo_matrix_t cur_mat;
-    SMIL::RegionBase::BackgroundRepeat bg_repeat;
-    ImageData *bg_image;
     float opacity;
     bool toplevel;
 
@@ -220,10 +220,8 @@ public:
 KDE_NO_CDTOR_EXPORT
 CairoPaintVisitor::CairoPaintVisitor (cairo_surface_t * cs, Matrix m,
         const IRect & rect, QColor c, bool top)
- : clip (rect), cairo_surface (cs),
-   matrix (m),
-   bg_repeat (SMIL::RegionBase::BgRepeat), bg_image (NULL),
-   toplevel (top) {
+ : PaintContext (m, rect), cairo_surface (cs), toplevel (top)
+{
     cr = cairo_create (cs);
     if (toplevel) {
         cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
@@ -304,12 +302,10 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::RegionBase *reg) {
         IRect scr = matrix.toScreen (rect);
         if (clip.intersect (scr).isEmpty ())
             return;
-        Matrix m = matrix;
+        PaintContext ctx_save = *(PaintContext *) this;
         matrix = Matrix (rect.x(), rect.y(), s->xscale, s->yscale);
-        matrix.transform (m);
-        IRect clip_save = clip;
+        matrix.transform (ctx_save.matrix);
         clip = clip.intersect (scr);
-        SMIL::RegionBase::BackgroundRepeat bg_repeat_save = bg_repeat;
         if (SMIL::RegionBase::BgInherit != reg->bg_repeat)
             bg_repeat = reg->bg_repeat;
         cairo_save (cr);
@@ -318,11 +314,13 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::RegionBase *reg) {
         if (!s->virtual_size.isEmpty ())
             matrix.translate (-s->x_scroll, -s->y_scroll);
 
+        if (fit_default != reg->fit)
+            fit = reg->fit;
+
         ImageMedia *im = reg->media_info
             ? (ImageMedia *) reg->media_info->media
             : NULL;
 
-        ImageData *bg_save = bg_image;
         ImageData *bg_img = im && !im->isEmpty() ? im->cached_img.ptr () : NULL;
         if (reg->background_image == "inherit")
             bg_img = bg_image;
@@ -466,10 +464,7 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::RegionBase *reg) {
             }
         }
         cairo_restore (cr);
-        bg_image = bg_save;
-        matrix = m;
-        bg_repeat = bg_repeat_save;
-        clip = clip_save;
+        *(PaintContext *) this = ctx_save;
         s->dirty = false;
     }
 }
@@ -661,6 +656,12 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::RefMediaType *ref) {
     }
     if (!ref->media_info)
         return;
+    if (fit_default != fit
+            && fit_default == ref->fit
+            && fit != ref->effective_fit) {
+        ref->effective_fit = fit;
+        s->resize (ref->calculateBounds(), false);
+    }
     if (ref->media_info->media &&
             ref->media_info->media->type () == MediaManager::Image) {
         if (!s)
@@ -856,7 +857,8 @@ KDE_NO_EXPORT void CairoPaintVisitor::visit (SMIL::TextMediaType * txt) {
         Single ft_size = w * txt->font_size / (double)s->bounds.width ();
         bool clear = s->surface;
 
-        QFont font (txt->font_name, ft_size);
+        QFont font (txt->font_name);
+        font.setPixelSize(ft_size);
         if (clear) {
             pxw = scr.width ();
             pxh = scr.height ();
@@ -1058,7 +1060,8 @@ void SmilTextVisitor::push () {
         fs *= scale;
         maxfs *= scale;
 
-        QFont font ("Sans", (int)fs);
+        QFont font ("Sans");
+        font.setPixelSize((int)fs);
         calculateTextDimensions (font, rich_text.toUtf8 ().constData (),
                 width, 2 * maxfs, 1024, &pxw, &pxh, true, info.props.text_align);
         int x = 0;
@@ -1588,7 +1591,7 @@ static void followLink (SMIL::LinkingBase * link) {
     } else {
         PlayListNotify *notify = link->document ()->notify_listener;
         if (notify && !link->target.isEmpty ()) {
-            notify->openUrl (link->href, link->target, QString ());
+            notify->openUrl(KUrl(link->href), link->target, QString());
         } else {
             NodePtr n = link;
             for (NodePtr p = link->parentNode (); p; p = p->parentNode ()) {
@@ -1747,13 +1750,15 @@ namespace KMPlayer {
 class KMPLAYER_NO_EXPORT ViewerAreaPrivate {
 public:
     ViewerAreaPrivate (ViewArea *v)
-        : m_view_area (v), backing_store (0),
-          width (0), height (0), have_gc (false) {
-    }
+        : m_view_area (v), backing_store (0), gc(0),
+          screen(NULL), visual(NULL), width(0), height(0)
+    {}
     ~ViewerAreaPrivate() {
         destroyBackingStore ();
-        if (have_gc)
-            XFreeGC (QX11Info::display (), gc);
+        if (gc) {
+            xcb_connection_t* connection = QX11Info::connection();
+            xcb_discard_reply(connection, xcb_free_gc(connection, gc).sequence);
+        }
     }
     void clearSurface (Surface *s) {
 #ifdef KMPLAYER_WITH_CAIRO
@@ -1777,53 +1782,80 @@ public:
     }
 #ifdef KMPLAYER_WITH_CAIRO
     cairo_surface_t *createSurface (int w, int h) {
-        Display * display = QX11Info::display ();
+        xcb_connection_t* connection = QX11Info::connection();
         destroyBackingStore ();
-        backing_store = XCreatePixmap (display,
-                m_view_area->winId (), w, h, QX11Info::appDepth ());
-        width = w;
-        height = h;
-        return cairo_xlib_surface_create (display, backing_store,
-                DefaultVisual (display, DefaultScreen (display)), w, h);
-        /*return cairo_xlib_surface_create_with_xrender_format (
-            QX11Info::display (),
-            id,
-            DefaultScreenOfDisplay (QX11Info::display ()),
-            XRenderFindVisualFormat (QX11Info::display (),
-                DefaultVisual (QX11Info::display (),
-                    DefaultScreen (QX11Info::display ()))),
-            w, h);*/
+        xcb_screen_t* scr = screen_of_display(connection, QX11Info::appScreen());
+        backing_store = xcb_generate_id(connection);
+        xcb_void_cookie_t cookie = xcb_create_pixmap_checked(connection, scr->root_depth, backing_store, m_view_area->winId(), w, h);
+        xcb_generic_error_t* error = xcb_request_check(connection, cookie);
+        if (error) {
+            qDebug("failed to create pixmap");
+            return NULL;
+        }
+        return cairo_xcb_surface_create(connection, backing_store, visual_of_screen(connection, scr), w, h);
     }
     void swapBuffer (const IRect &sr, int dx, int dy) {
-        if (!have_gc) {
-            XGCValues values;
-            values.graphics_exposures = false;
-            values.function = GXcopy;
-            values.fill_style = FillSolid;
-            values.subwindow_mode = ClipByChildren;
-            gc = XCreateGC (QX11Info::display (), backing_store,
-                    GCGraphicsExposures | GCFunction |
-                    GCFillStyle | GCSubwindowMode, &values);
-            have_gc = true;
+        xcb_connection_t* connection = QX11Info::connection();
+        if (!gc) {
+            gc = xcb_generate_id(connection);
+            uint32_t values[] = { XCB_GX_COPY, XCB_FILL_STYLE_SOLID,
+                XCB_SUBWINDOW_MODE_CLIP_BY_CHILDREN, 0 };
+            xcb_discard_reply(connection, xcb_create_gc(connection, gc, backing_store,
+                    XCB_GC_FUNCTION | XCB_GC_FILL_STYLE |
+                    XCB_GC_SUBWINDOW_MODE | XCB_GC_GRAPHICS_EXPOSURES, values).sequence);
         }
-        XCopyArea (QX11Info::display(), backing_store, m_view_area->winId(),
-                gc, sr.x(), sr.y(), sr.width (), sr.height (), dx, dy);
-        XFlush (QX11Info::display());
+        xcb_discard_reply(connection, xcb_copy_area(connection, backing_store, m_view_area->winId(),
+                gc, sr.x(), sr.y(), dx, dy, sr.width (), sr.height ()).sequence);
+        xcb_flush(connection);
     }
 #endif
     void destroyBackingStore () {
 #ifdef KMPLAYER_WITH_CAIRO
-        if (backing_store)
-            XFreePixmap (QX11Info::display(), backing_store);
+        if (backing_store) {
+            xcb_connection_t* connection = QX11Info::connection();
+            xcb_discard_reply(connection, xcb_free_pixmap(connection, backing_store).sequence);
+        }
 #endif
         backing_store = 0;
     }
+    xcb_screen_t *screen_of_display(xcb_connection_t* c, int num)
+    {
+        if (!screen) {
+            xcb_screen_iterator_t iter;
+
+            iter = xcb_setup_roots_iterator (xcb_get_setup (c));
+            for (; iter.rem; --num, xcb_screen_next (&iter))
+                if (num == 0) {
+                    screen = iter.data;
+                    break;
+                }
+        }
+        return screen;
+    }
+
+    xcb_visualtype_t* visual_of_screen(xcb_connection_t* c, xcb_screen_t* screen)
+    {
+        if (!visual) {
+            xcb_depth_iterator_t depth_iter = xcb_screen_allowed_depths_iterator (screen);
+            for (; depth_iter.rem; xcb_depth_next (&depth_iter)) {
+                xcb_visualtype_iterator_t visual_iter = xcb_depth_visuals_iterator (depth_iter.data);
+                for (; visual_iter.rem; xcb_visualtype_next (&visual_iter)) {
+                    if (screen->root_visual == visual_iter.data->visual_id) {
+                        visual = visual_iter.data;
+                        break;
+                    }
+                }
+            }
+        }
+        return visual;
+    }
     ViewArea *m_view_area;
-    Drawable backing_store;
-    GC gc;
+    xcb_drawable_t backing_store;
+    xcb_gcontext_t gc;
+    xcb_screen_t* screen;
+    xcb_visualtype_t* visual;
     int width;
     int height;
-    bool have_gc;
 };
 
 class KMPLAYER_NO_EXPORT RepaintUpdater {
@@ -1845,6 +1877,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (QWidget *, View * view, bool paint_bg)
    surface (new Surface (this)),
    m_mouse_invisible_timer (0),
    m_repaint_timer (0),
+   m_restore_fullscreen_timer (0),
    m_fullscreen (false),
    m_minimal (false),
    m_updaters_enabled (true),
@@ -1858,7 +1891,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (QWidget *, View * view, bool paint_bg)
     //new KAction (i18n ("Fullscreen"), KShortcut (Qt::Key_F), this, SLOT (accelActivated ()), m_collection, "view_fullscreen_toggle");
     setMouseTracking (true);
     setFocusPolicy (Qt::ClickFocus);
-    kapp->installX11EventFilter (this);
+    kapp->installNativeEventFilter(this);
 }
 
 KDE_NO_CDTOR_EXPORT ViewArea::~ViewArea () {
@@ -1879,21 +1912,27 @@ KDE_NO_EXPORT void ViewArea::stopTimers () {
 KDE_NO_EXPORT void ViewArea::fullScreen () {
     stopTimers ();
     if (m_fullscreen) {
-        setWindowState( windowState() & ~Qt::WindowFullScreen ); // reset
-        m_view->dockArea ()->setCentralWidget (this);
-        m_view->dockArea ()->restoreState (m_dock_state);
-        for (unsigned i = 0; i < m_collection->count (); ++i)
+        setVisible(false);
+        setWindowState(windowState() & ~Qt::WindowFullScreen); // reset
+        if (!m_restore_fullscreen_timer)
+            m_restore_fullscreen_timer = startTimer(25);
+        for (int i = 0; i < m_collection->count (); ++i)
             m_collection->action (i)->setEnabled (false);
-        m_view->controlPanel ()->button (ControlPanel::button_playlist)->setIconSet (QIconSet (QPixmap (playlist_xpm)));
+        m_view->controlPanel()->enableFullscreenButton(false);
         unsetCursor();
     } else {
-        m_dock_state = m_view->dockArea ()->saveState ();
         m_topwindow_rect = topLevelWidget ()->geometry ();
-        reparent (0L, 0, qApp->desktop()->screenGeometry(this).topLeft(), true);
-        setWindowState( windowState() | Qt::WindowFullScreen ); // set
-        for (unsigned i = 0; i < m_collection->count (); ++i)
+#if QT_VERSION >= 0x050200
+        m_view->dockArea()->takeCentralWidget();
+#else
+        setParent (0L);
+#endif
+        move(qApp->desktop()->screenGeometry(this).topLeft());
+        setVisible(true);
+        setWindowState( windowState() ^ Qt::WindowFullScreen ); // set
+        for (int i = 0; i < m_collection->count (); ++i)
             m_collection->action (i)->setEnabled (true);
-        m_view->controlPanel ()->button (ControlPanel::button_playlist)->setIconSet (QIconSet (QPixmap (normal_window_xpm)));
+        m_view->controlPanel()->enableFullscreenButton(true);
         m_mouse_invisible_timer = startTimer(MOUSE_INVISIBLE_DELAY);
     }
     m_fullscreen = !m_fullscreen;
@@ -1911,11 +1950,11 @@ void ViewArea::minimalMode () {
         m_view->setViewOnly ();
         m_view->setControlPanelMode (KMPlayer::View::CP_AutoHide);
         m_view->setNoInfoMessages (true);
-        m_view->controlPanel ()->button (ControlPanel::button_playlist)->setIconSet (QIconSet (QPixmap (normal_window_xpm)));
+        m_view->controlPanel()->enableFullscreenButton(true);
     } else {
         m_view->setControlPanelMode (KMPlayer::View::CP_Show);
         m_view->setNoInfoMessages (false);
-        m_view->controlPanel ()->button (ControlPanel::button_playlist)->setIconSet (QIconSet (QPixmap (playlist_xpm)));
+        m_view->controlPanel()->enableFullscreenButton(false);
     }
     m_topwindow_rect = topLevelWidget ()->geometry ();
 }
@@ -1948,7 +1987,7 @@ KDE_NO_EXPORT void ViewArea::mouseDoubleClickEvent (QMouseEvent *) {
 }
 
 KDE_NO_EXPORT void ViewArea::mouseMoveEvent (QMouseEvent * e) {
-    if (e->state () == Qt::NoButton)
+    if (e->buttons () == Qt::NoButton)
         m_view->mouseMoved (e->x (), e->y ());
     if (surface->node) {
         MouseVisitor visitor (this, MsgEventPointerMoved,
@@ -2031,7 +2070,7 @@ KDE_NO_EXPORT void ViewArea::syncVisual () {
 #endif
     {
         m_update_rect = IRect ();
-        repaint (QRect(rect.x(), rect.y(), rect.width(), rect.height()), false);
+        repaint (QRect(rect.x(), rect.y(), rect.width(), rect.height()));
     }
 }
 
@@ -2225,6 +2264,16 @@ KDE_NO_EXPORT void ViewArea::timerEvent (QTimerEvent * e) {
             killTimer (m_repaint_timer);
             m_repaint_timer = 0;
         }
+    } else if (e->timerId () == m_restore_fullscreen_timer) {
+        xcb_connection_t* connection = QX11Info::connection();
+        xcb_get_window_attributes_cookie_t cookie = xcb_get_window_attributes(connection, winId());
+        xcb_get_window_attributes_reply_t* attrs = xcb_get_window_attributes_reply(connection, cookie, NULL);
+        if (attrs->map_state == XCB_MAP_STATE_UNMAPPED) {
+            m_view->dockArea ()->setCentralWidget (this);
+            killTimer(m_restore_fullscreen_timer);
+            m_restore_fullscreen_timer = 0;
+        }
+        free(attrs);
     } else {
         kError () << "unknown timer " << e->timerId () << " " << m_repaint_timer << endl;
         killTimer (e->timerId ());
@@ -2234,7 +2283,7 @@ KDE_NO_EXPORT void ViewArea::timerEvent (QTimerEvent * e) {
 KDE_NO_EXPORT void ViewArea::closeEvent (QCloseEvent * e) {
     //kDebug () << "closeEvent";
     if (m_fullscreen) {
-        fullScreen ();
+        m_view->fullScreen();
         if (!m_view->topLevelWidget ()->isVisible ())
             m_view->topLevelWidget ()->setVisible (true);
         e->ignore ();
@@ -2252,11 +2301,11 @@ IViewer *ViewArea::createVideoWidget () {
 }
 
 void ViewArea::destroyVideoWidget (IViewer *widget) {
-    VideoWidgetList::iterator it = video_widgets.find (widget);
-    if (it != video_widgets.end ()) {
-        IViewer *viewer = *it;
+    int i = video_widgets.indexOf(widget);
+    if (i >= 0) {
+        IViewer *viewer = widget;
         delete viewer;
-        video_widgets.erase (it);
+        video_widgets.removeAt(i);
     } else {
         kWarning () << "destroyVideoWidget widget not found" << endl;
     }
@@ -2268,97 +2317,110 @@ void ViewArea::setVideoWidgetVisible (bool show) {
         static_cast <VideoOutput *> (*it)->setVisible (show);
 }
 
-static void setXSelectInput (WId wid, long mask) {
-    WId r, p, *c;
-    unsigned int nr;
-    XSelectInput (QX11Info::display (), wid, mask);
-    if (XQueryTree (QX11Info::display (), wid, &r, &p, &c, &nr)) {
-        for (int i = 0; i < nr; ++i)
-            setXSelectInput (c[i], mask);
-        XFree (c);
+static void setXSelectInput(WId wid, uint32_t mask) {
+    xcb_connection_t* connection = QX11Info::connection();
+    const uint32_t values[] = { mask };
+    xcb_void_cookie_t cookie = xcb_change_window_attributes(connection, wid, XCB_CW_EVENT_MASK, values);
+    xcb_discard_reply(connection, cookie.sequence);
+    xcb_query_tree_cookie_t biscuit = xcb_query_tree(connection, wid);
+    xcb_query_tree_reply_t *reply = xcb_query_tree_reply(connection, biscuit, NULL);
+    if (reply) {
+        xcb_window_t *chlds = xcb_query_tree_children(reply);
+        for (int i = 0; i < xcb_query_tree_children_length(reply); i++)
+            setXSelectInput(chlds[i], mask);
+        free(reply);
+    } else {
+        qDebug("failed to get x children");
     }
 }
 
-bool ViewArea::x11Event (XEvent *xe) {
-    switch (xe->type) {
-        case UnmapNotify: {
+bool ViewArea::nativeEventFilter(const QByteArray& eventType, void * message, long *result) {
+    if (eventType != "xcb_generic_event_t")
+        return false;
+
+    xcb_generic_event_t* event = (xcb_generic_event_t*)message;
+    switch (event->response_type & ~0x80) {
+    case XCB_UNMAP_NOTIFY: {
+        xcb_unmap_notify_event_t* ev = (xcb_unmap_notify_event_t*)event;
+        if (ev->event != ev->window) {
             const VideoWidgetList::iterator e = video_widgets.end ();
-            for (VideoWidgetList::iterator it = video_widgets.begin(); it != e; ++it) {
-                if ((*it)->clientHandle () == xe->xunmap.event) {
-                    m_view->videoStart ();
+            for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i) {
+                if (ev->event == (*i)->ownHandle()) {
+                    (*i)->embedded(0);
                     break;
                 }
             }
-            break;
         }
-        case XKeyPress: {
+        break;
+    }
+    case XCB_MAP_NOTIFY: {
+        xcb_map_notify_event_t* ev = (xcb_map_notify_event_t*)event;
+        if (!ev->override_redirect && ev->event != ev->window) {
+            xcb_connection_t* connection = QX11Info::connection();
             const VideoWidgetList::iterator e = video_widgets.end ();
-            for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i)
-                if ((*i)->clientHandle () == xe->xkey.window &&
-                        static_cast <VideoOutput *>(*i)->inputMask() & KeyPressMask) {
-                    KeySym ksym;
-                    char kbuf[16];
-                    XLookupString (&xe->xkey, kbuf, sizeof(kbuf), &ksym, NULL);
-                    switch (ksym) {
-                        case XK_f:
-                        case XK_F:
-                            m_view->fullScreen ();
-                            break;
-                    }
+            for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i) {
+                if (ev->event == (*i)->ownHandle()) {
+                    (*i)->embedded(ev->window);
+                    return false;
                 }
-            break;
+                xcb_window_t p = ev->event;
+                xcb_window_t w = ev->window;
+                xcb_window_t v = (*i)->clientHandle ();
+                xcb_window_t va = winId ();
+                xcb_window_t root = 0;
+                while (p != v) {
+                    xcb_query_tree_cookie_t cookie = xcb_query_tree(connection, w);
+                    xcb_query_tree_reply_t *reply = xcb_query_tree_reply(connection, cookie, NULL);
+                    if (reply) {
+                        p = reply->parent;
+                        root = reply->root;
+                        free(reply);
+                    } else {
+                        qDebug("failed to get x parent");
+                        break;
+                    }
+                    if (p == va || p == v || p == root)
+                        break;
+                    w = p;
+                }
+                if (p == v) {
+                    setXSelectInput (ev->window,
+                            static_cast <VideoOutput *>(*i)->inputMask ());
+                    break;
+                }
+            }
         }
-        /*case ColormapNotify:
-            fprintf (stderr, "colormap notify\n");
-            return true;*/
-        case MotionNotify:
-            if (m_view->controlPanelMode () == View::CP_AutoHide) {
-                const VideoWidgetList::iterator e = video_widgets.end ();
-                for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i) {
-                    QPoint p = mapToGlobal (QPoint (0, 0));
-                    int x = xe->xmotion.x_root - p.x ();
-                    int y = xe->xmotion.y_root - p.y ();
-                    m_view->mouseMoved (x, y);
-                    if (x > 0 && x < width () && y > 0 && y < height ())
-                        mouseMoved ();
-                }
+        break;
+    }
+    case XCB_MOTION_NOTIFY: {
+        xcb_motion_notify_event_t* ev = (xcb_motion_notify_event_t*)event;
+        if (m_view->controlPanelMode () == View::CP_AutoHide) {
+            const VideoWidgetList::iterator e = video_widgets.end ();
+            for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i) {
+                QPoint p = mapToGlobal (QPoint (0, 0));
+                int x = ev->root_x - p.x ();
+                int y = ev->root_y - p.y ();
+                m_view->mouseMoved (x, y);
+                if (x > 0 && x < width () && y > 0 && y < height ())
+                    mouseMoved ();
             }
-            break;
-        case MapNotify:
-            if (!xe->xmap.override_redirect) {
-                const VideoWidgetList::iterator e = video_widgets.end ();
-                for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i) {
-                    WId p = xe->xmap.event;
-                    WId w = xe->xmap.window;
-                    WId v = (*i)->clientHandle ();
-                    WId va = winId ();
-                    WId root = 0;
-                    WId *children;
-                    unsigned int nr;
-                    while (p != v &&
-                            XQueryTree (QX11Info::display (), w, &root,
-                                &p, &children, &nr)) {
-                        if (nr)
-                            XFree (children);
-                        if (p == va || p == v || p == root)
-                            break;
-                        w = p;
-                    }
-                    if (p == v)
-                        setXSelectInput (xe->xmap.window,
-                                static_cast <VideoOutput *>(*i)->inputMask ());
-                }
-                /*if (e->xmap.event == m_viewer->clientWinId ()) {
-                  show ();
-                  QTimer::singleShot (10, m_viewer, SLOT (sendConfigureEvent ()));
-                  }*/
+        }
+        break;
+    }
+    case XCB_KEY_PRESS: {
+        xcb_key_press_event_t* ev = (xcb_key_press_event_t*)event;
+        const VideoWidgetList::iterator e = video_widgets.end ();
+        for (VideoWidgetList::iterator i=video_widgets.begin(); i != e; ++i)
+            if ((*i)->clientHandle () == ev->event &&
+                    static_cast <VideoOutput *>(*i)->inputMask() & XCB_EVENT_MASK_KEY_PRESS) {
+                if (ev->detail == 41 /*FIXME 'f'*/)
+                    m_view->fullScreen ();
+                break;
             }
-            break;
-        /*case ConfigureNotify:
-            break;
-            //return true;*/
-        default:
-            break;
+        break;
+    }
+    default:
+        break;
     }
     return false;
 }
@@ -2367,56 +2429,62 @@ bool ViewArea::x11Event (XEvent *xe) {
 
 KDE_NO_CDTOR_EXPORT VideoOutput::VideoOutput (QWidget *parent, View * view)
   : QX11EmbedContainer (parent),
-    m_plain_window (0), resized_timer (0),
+    m_plain_window(0), m_client_window(0), resized_timer(0),
     m_bgcolor (0), m_aspect (0.0),
-    m_view (view) {
-    /*XWindowAttributes xwa;
-    XGetWindowAttributes (QX11Info::display(), winId (), &xwa);
-    XSetWindowAttributes xswa;
-    xswa.background_pixel = 0;
-    xswa.border_pixel = 0;
-    xswa.colormap = xwa.colormap;
-    create (XCreateWindow (QX11Info::display()), parent->winId (), 0, 0, 10, 10, 0, 
-                           x11Depth (), InputOutput, (Visual*)x11Visual (),
-                           CWBackPixel | CWBorderPixel | CWColormap, &xswa));*/
+    m_view (view)
+{
     setAcceptDrops (true);
-    connect (this, SIGNAL (clientIsEmbedded ()), this, SLOT (embedded ()));
     connect (view->viewArea (), SIGNAL (fullScreenChanged ()),
              this, SLOT (fullScreenChanged ()));
     kDebug() << "VideoOutput::VideoOutput" << endl;
     setMonitoring (MonitorAll);
     setAttribute (Qt::WA_NoSystemBackground, true);
+
+    xcb_connection_t* connection = QX11Info::connection();
+    xcb_get_window_attributes_cookie_t cookie = xcb_get_window_attributes(connection, winId());
+    xcb_get_window_attributes_reply_t* attrs = xcb_get_window_attributes_reply(connection, cookie, NULL);
+    if (!(attrs->your_event_mask & XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY))
+        setXSelectInput(winId(), attrs->your_event_mask | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY);
+    free(attrs);
     //setProtocol (QXEmbed::XPLAIN);
 }
 
 KDE_NO_CDTOR_EXPORT VideoOutput::~VideoOutput () {
     kDebug() << "VideoOutput::~VideoOutput" << endl;
+    if (m_plain_window) {
+        xcb_connection_t* connection = QX11Info::connection();
+        xcb_destroy_window(connection, m_plain_window);
+        xcb_flush(connection);
+        m_plain_window = 0;
+    }
 }
 
 void VideoOutput::useIndirectWidget (bool inderect) {
     kDebug () << "setIntermediateWindow " << !!m_plain_window << "->" << inderect;
     if (!clientWinId () || !!m_plain_window != inderect) {
+        xcb_connection_t* connection = QX11Info::connection();
         if (inderect) {
             if (!m_plain_window) {
-                int scr = DefaultScreen (QX11Info::display ());
-                m_plain_window = XCreateSimpleWindow (
-                        QX11Info::display(),
-                        winId (),
+                xcb_screen_t* scr = m_view->viewArea()->d->screen_of_display(connection, QX11Info::appScreen());
+                m_plain_window = xcb_generate_id(connection);
+                uint32_t values[] = { scr->black_pixel, m_input_mask };
+                xcb_create_window(connection,
+                        XCB_COPY_FROM_PARENT, m_plain_window, winId(),
                         0, 0, width(), height(),
-                        1,
-                        BlackPixel (QX11Info::display(), scr),
-                        BlackPixel (QX11Info::display(), scr));
-                XMapWindow (QX11Info::display(), m_plain_window);
-                XSync (QX11Info::display (), false);
+                        1, XCB_WINDOW_CLASS_INPUT_OUTPUT, XCB_COPY_FROM_PARENT,
+                        XCB_CW_BACK_PIXEL | XCB_CW_EVENT_MASK, values);
+                xcb_map_window(connection, m_plain_window);
+                xcb_flush(connection);
+                //XSync (QX11Info::display (), false);
                 //embedClient (m_plain_window);
             }
-            XClearWindow (QX11Info::display(), m_plain_window);
+            //XClearWindow (QX11Info::display(), m_plain_window);
         } else {
             if (m_plain_window) {
-                XUnmapWindow (QX11Info::display(), m_plain_window);
-                XFlush (QX11Info::display());
+                xcb_unmap_window(connection, m_plain_window);
                 discardClient ();
-                XDestroyWindow (QX11Info::display(), m_plain_window);
+                xcb_destroy_window(connection, m_plain_window);
+                xcb_flush(connection);
                 m_plain_window = 0;
                 //XSync (QX11Info::display (), false);
             }
@@ -2424,12 +2492,12 @@ void VideoOutput::useIndirectWidget (bool inderect) {
     }
 }
 
-KDE_NO_EXPORT void VideoOutput::embedded () {
+KDE_NO_EXPORT void VideoOutput::embedded(WindowId handle) {
     kDebug () << "[01;35mwindowChanged[00m " << (int)clientWinId ();
-    //QTimer::singleShot (10, this, SLOT (sendConfigureEvent ()));
+    m_client_window = handle;
     if (clientWinId () && !resized_timer)
          resized_timer = startTimer (50);
-    if (clientWinId ())
+    if (clientWinId())
         setXSelectInput (clientWinId (), m_input_mask);
 }
 
@@ -2442,9 +2510,15 @@ KDE_NO_EXPORT void VideoOutput::timerEvent (QTimerEvent *e) {
     if (e->timerId () == resized_timer) {
         killTimer (resized_timer);
         resized_timer = 0;
-        if (clientWinId ())
-            XMoveResizeWindow (QX11Info::display(), clientWinId (),
-                    0, 0, width (), height ());
+        if (clientWinId ()) {
+            xcb_connection_t* connection = QX11Info::connection();
+            uint32_t values[] = { 0, 0, width(), height() };
+            xcb_configure_window(connection, clientWinId(),
+                    XCB_CONFIG_WINDOW_X | XCB_CONFIG_WINDOW_Y |
+                    XCB_CONFIG_WINDOW_WIDTH | XCB_CONFIG_WINDOW_HEIGHT,
+                    values);
+            xcb_flush(connection);
+        }
     }
 }
 
@@ -2453,6 +2527,10 @@ WindowId VideoOutput::windowHandle () {
     return m_plain_window ? m_plain_window : winId ();
 }
 
+WindowId VideoOutput::ownHandle () {
+    return winId ();
+}
+
 WindowId VideoOutput::clientHandle () {
     return clientWinId ();
 }
@@ -2497,23 +2575,23 @@ KDE_NO_EXPORT void VideoOutput::setMonitoring (Monitor m) {
         //KeyPressMask | KeyReleaseMask |
         //EnterWindowMask | LeaveWindowMask |
         //FocusChangeMask |
-        ExposureMask |
+        XCB_EVENT_MASK_EXPOSURE |
         //StructureNotifyMask |
-        SubstructureNotifyMask;
+        XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY;
     if (m & MonitorMouse)
-        m_input_mask |= PointerMotionMask;
+        m_input_mask |= XCB_EVENT_MASK_POINTER_MOTION;
     if (m & MonitorKey)
-        m_input_mask |= KeyPressMask;
+        m_input_mask |= XCB_EVENT_MASK_KEY_PRESS;
     if (clientWinId ())
         setXSelectInput (clientWinId (), m_input_mask);
 }
 
 KDE_NO_EXPORT void VideoOutput::fullScreenChanged () {
-    if (!(m_input_mask & KeyPressMask)) { // FIXME: store monitor when needed
+    if (!(m_input_mask & XCB_EVENT_MASK_KEY_PRESS)) { // FIXME: store monitor when needed
         if (m_view->isFullScreen ())
-            m_input_mask |= PointerMotionMask;
+            m_input_mask |= XCB_EVENT_MASK_POINTER_MOTION;
         else
-            m_input_mask &= ~PointerMotionMask;
+            m_input_mask &= ~XCB_EVENT_MASK_POINTER_MOTION;
     }
     if (clientWinId ())
         setXSelectInput (clientWinId (), m_input_mask);
@@ -2532,38 +2610,6 @@ KDE_NO_EXPORT void VideoOutput::dropEvent (QDropEvent * de) {
 KDE_NO_EXPORT void VideoOutput::dragEnterEvent (QDragEnterEvent* dee) {
     m_view->dragEnterEvent (dee);
 }
-/*
-*/
-void VideoOutput::sendKeyEvent (int key) {
-    WId w = clientWinId ();
-    if (w) {
-        char buf[2] = { char (key), '\0' };
-        KeySym keysym = XStringToKeysym (buf);
-        XKeyEvent event = {
-            XKeyPress, 0, true,
-            QX11Info::display (), w, QX11Info::appRootWindow(), w,
-            /*time*/ 0, 0, 0, 0, 0,
-            0, XKeysymToKeycode (QX11Info::display (), keysym), true
-        };
-        XSendEvent (QX11Info::display(), w, false, KeyPressMask, (XEvent *) &event);
-        XFlush (QX11Info::display ());
-    }
-}
-
-KDE_NO_EXPORT void VideoOutput::sendConfigureEvent () {
-    WId w = clientWinId ();
-    kDebug() << "[01;35msendConfigureEvent[00m " << width ();
-    if (w) {
-        XConfigureEvent c = {
-            ConfigureNotify, 0UL, True,
-            QX11Info::display (), w, winId (),
-            x (), y (), width (), height (),
-            0, None, False
-        };
-        XSendEvent(QX11Info::display(),c.event,true,StructureNotifyMask,(XEvent*)&c);
-        XFlush (QX11Info::display ());
-    }
-}
 
 KDE_NO_EXPORT void VideoOutput::contextMenuEvent (QContextMenuEvent * e) {
     m_view->controlPanel ()->popupMenu->exec (e->globalPos ());
@@ -2584,10 +2630,11 @@ KDE_NO_EXPORT void VideoOutput::setCurrentBackgroundColor (const QColor & c) {
     QPalette palette;
     palette.setColor (backgroundRole(), c);
     setPalette (palette);
-    WId w = clientWinId ();
-    if (w) {
-        XSetWindowBackground (QX11Info::display (), w, c.rgb ());
-        XFlush (QX11Info::display ());
+    if (clientWinId()) {
+        xcb_connection_t* connection = QX11Info::connection();
+        const uint32_t values[] = { c.rgb() };
+        xcb_change_window_attributes(connection, clientWinId(), XCB_CW_BACK_PIXEL, values);
+        xcb_flush(connection);
     }
 }
 
